********************************************************************************
********************************************************************************
*** Tables for the main paper *** Tables for the main paper 
********************************************************************************
********************************************************************************

**** define global pair covariates:
global pair lnBL lndis river ethnic_connection same_language colonial_ties lnFR MT_1000 MT_2000 
global pair_all lndis border_n ethnic_connection same_language colonial_ties 
global conflict lnConflict lnCivillian lnDeath lnUnknown

*** Afrobarometer code cannot be run unless dataaccess has been granted by
/*
BenYishay, A., Rotberg, R., Wells, J., Lv, Z., Goodman, S., Kovacevic, L., Runfola, D. 2017. 
Geocoding Afrobarometer Rounds 1 – 6: Methodology & Data Quality. AidData. Available online at http://geo.aiddata.org.
*/

********************************************************************************
*** Table 1: 
*** Nighttime Lights:
********************************************************************************

use "$data/NTL_Trade_Data.dta", clear

cap drop Trade_Expos*
gen Trade_Exposure = lnExport*popshare_tribe
gen Trade_Exposure_OLS = lnOLS_SM_Border*popshare_tribe
gen Trade_Exposure_PPML = lnPPML_SM_Border*popshare_tribe

tab status
cap drop EPR
gen EPR = 0 if status=="DISCRIMINATED"|status=="POWERLESS"
replace EPR = 1 if status=="JUNIOR PARTNER"|status=="SENIOR PARTNER"	// Junior partys
replace EPR = 2 if status=="MONOPOLY"|status=="DOMINANT"	// Dominating
tab EPR


cap drop InPower Trade_InPower
recode EPR (0 1 = 0) (2 = 1) , gen(InPower)

gen Trade_InPower = Trade_Exposure*InPower

eststo clear
qui   {
		
	eststo: reghdfe Lid Trade_Exposure , a(country_code##year country_code##tribe_code ) cl(country_code#tribe_code) tol(1e-4)

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		su Lid if e(sample)
		estadd scalar MEAN `r(mean)'
		
	eststo: reghdfe Lid Trade_Exposure Trade_InPower , a(country_code##year##InPower country_code##tribe_code ) cl(country_code#tribe_code) tol(1e-4)

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		su Lid if e(sample)
		estadd scalar MEAN `r(mean)'		
		
	eststo: reghdfe lnNTL Trade_Exposure , a(country_code##year country_code##tribe_code ) cl(country_code#tribe_code) tol(1e-4)

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		su NTL if e(sample)
		estadd scalar MEAN `r(mean)'		
	
	eststo: reghdfe lnNTL Trade_Exposure Trade_InPower , a(country_code##year##InPower country_code##tribe_code ) cl(country_code#tribe_code) tol(1e-4)

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"		
		su NTL if e(sample)
		estadd scalar MEAN `r(mean)'	
	
}

esttab, drop(_cons  ) star(* 0.1 ** 0.05 *** 0.01)  stat(countryyear Ethniccountry MEAN N )


esttab  using "$tables/T1_NTL.tex" ///
		, replace booktabs fragment ///
		keep(Trade_Exposure Trade_InPower  ) cells(b(fmt(%9.3f) star  label(" ")) se(par label(" ") ))   ///
		star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
		coeflabel(Trade_Exposure "Trade Exposure" Trade_InPower "Trade Exposure \(\times\) In Power") ///
		nomtitles nonumbers nodepvars noobs nonote nogaps noline ///
		substitute(\_ _ / ) 
		
// bring panels together
	#delimit ;
	esttab using "$tables/M1_NTL_Panel.tex", replace booktabs
		cells(none) nonote noobs nomtitles ///
		mgroups("Fraction lit" "Average luminosity" , pattern(1 0 1 0   ) 
		prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
		prefoot( 
		\panelinput{"$tables/T1_NTL.tex"} 
		\\
		\midrule 
		)
		substitute(\_ _)	
	stats( countryyear Ethniccountry N MEAN, ///
		label("Country \(\times\) year fixed effects" "Country \(\times\) ethnicity fixed effects" "Observations" "Mean dependent variable") fmt(a a %9.0fc %9.3f )) 
	;
	#delimit cr		
		
		
********************************************************************************
*** Table 2: 
*** Wealth:
********************************************************************************		

use "$data/Afrobarometer_Trade.dta", clear

* Dependent Variable
cap drop Trade_Expos*
gen Trade_Exposure = lnExport*popshare_tribe
gen Trade_Exposure_OLS = lnOLS_EN_Border*popshare_tribe
gen Trade_Exposure_PPML = lnPPML_EN_Border*popshare_tribe

* Political variable

cap drop EPR
gen EPR = 0 if status=="DISCRIMINATED"|status=="POWERLESS"|status=="IRRELEVANT"|status=="STATE COLLAPSE"
replace EPR = 1 if status=="JUNIOR PARTNER"|status=="SENIOR PARTNER"	// Junior partys
replace EPR = 2 if status=="MONOPOLY"|status=="DOMINANT"	// Dominating
tab EPR

cap drop InPower Trade_InPower
recode EPR (0 1 = 0) (2 = 1) , gen(InPower)

* Interaction
gen Trade_InPower = Trade_Exposure*InPower
gen Trade_OLS_InPower = Trade_Exposure_OLS*InPower
gen Trade_PPML_InPower = Trade_Exposure_PPML*InPower

* Cluster:
gen cXe = country_code*1000+tribe_code

* Average Effect
eststo clear
qui foreach var of varlist z_Household z_Democracy z_Trust {
/*		
	eststo: reghdfe `var' c.Trade_Exposure , a(country_code##year country_code##tribe_code) cl(country_code#tribe_code) tol(1e-4)

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"					
		estadd local ind 	""	
	
	eststo: reghdfe `var' c.Trade_Exposure Trade_InPower, a(country_code##year##InPower country_code##tribe_code) cl(country_code#tribe_code) tol(1e-4)

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"					
		estadd local ind 	""	
*/		
	eststo: reghdfe `var' c.Trade_Exposure , a(country_code##year country_code##tribe_code Age Male Education Urban) cl(country_code#tribe_code) tol(1e-4)

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"					
		estadd local ind 	"Yes"				

	eststo: reghdfe `var' c.Trade_Exposure Trade_InPower, a(country_code##year##InPower country_code##tribe_code Age Male Education Urban) cl(country_code#tribe_code) tol(1e-4)

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"					
		estadd local ind 	"Yes"			
}		


esttab, drop(_cons  ) star(* 0.1 ** 0.05 *** 0.01)  stat(countryyear Ethniccountry ind N)


esttab  using "$tables/T2_AB.tex" ///
		, replace booktabs fragment ///
		keep(Trade_Exposure Trade_InPower  ) cells(b(fmt(%9.3f) star  label(" ")) se(par label(" ") ))   ///
		star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
		coeflabel(Trade_Exposure "Trade Exposure" Trade_InPower "Trade Exposure \(\times\) In Power") ///
		nomtitles nonumbers nodepvars noobs nonote nogaps noline ///
		substitute(\_ _ / ) 
		
// bring panels together
	#delimit ;
	esttab using "$tables/M2_AB_Panel.tex", replace booktabs
		cells(none) nonote noobs nomtitles ///
		mgroups("Household wealth" "Satisfaction with Democracy" "Trust in Institutions", pattern(1 0 1 0 1 0  ) 
		prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
		prefoot( 
		\panelinput{"$tables/T2_AB.tex"} 
		\\
		\midrule )
		substitute(\_ _)	
	stats( countryyear Ethniccountry ind N, ///
		label("Country \(\times\) year fixed effects" "Country \(\times\) ethnicity fixed effects" "Individual controls" "Observations" ) fmt(a a a %9.0fc )) 
	;
	#delimit cr			
	
	
********************************************************************************
*** Table 3: 
*** Ethnic Identification

********************************************************************************	
use "$data/Afrobarometer_Trade.dta", clear

* Dependent Variable
cap drop Trade_Expos*
gen Trade_Exposure = lnExport*popshare_tribe
gen Trade_Exposure_OLS = lnOLS_EN_Border*popshare_tribe
gen Trade_Exposure_PPML = lnPPML_EN_Border*popshare_tribe

* Political variable

cap drop EPR
gen EPR = 0 if status=="DISCRIMINATED"|status=="POWERLESS"|status=="IRRELEVANT"|status=="STATE COLLAPSE"
replace EPR = 1 if status=="JUNIOR PARTNER"|status=="SENIOR PARTNER"	// Junior partys
replace EPR = 2 if status=="MONOPOLY"|status=="DOMINANT"	// Dominating
tab EPR

cap drop InPower Trade_InPower
recode EPR (0 1 = 0) (2 = 1) , gen(InPower)

* Interaction
gen Trade_InPower = Trade_Exposure*InPower

* Cluster:
gen cXe = country_code*1000+tribe_code

tab year if Ethnic_Economic_Better!=.&Ethnic_Politic_Better!=.& Identify_Ethnic!=.& Ethnic_Treated_Unfair !=.


eststo clear
qui foreach var of varlist Ethnic_Economic_Better Ethnic_Politic_Better Identify_Ethnic Ethnic_Treated_Unfair  {

		
	qui eststo: reghdfe `var' Trade_Exposure Trade_InPower, a(country_code##year##InPower country_code##tribe_code Age Male Education Urban) /// 
		cl(country_code#tribe_code) tol(1e-4)

}
esttab, keep(Trade_Exposure Trade_InPower) star(* 0.1 ** 0.05 *** 0.01)

esttab using "$tables/T3_AB.tex" ///
		, replace booktabs fragment ///
		drop(_cons ) cells(b(fmt(%9.3f) star  label(" ")) se(par label(" ") ))   ///
		star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
		coeflabel(Trade_Exposure "Trade Exposure" Trade_InPower "Trade Exposure \(\times\) In Power") ///
		nomtitles nonumbers nodepvars noobs nonote nogaps noline ///
		substitute(\_ _ / ) 
		

		
********************************************************************************
*** Table 4: 
*** Mechanism 1:
********************************************************************************		
	

use "$data/NTL_Trade_Data.dta", clear

cap drop Trade_Expos*
gen Trade_Exposure = lnExport*popshare_tribe
gen Trade_Exposure_OLS = lnOLS_SM_Border*popshare_tribe
gen Trade_Exposure_PPML = lnPPML_SM_Border*popshare_tribe

tab status
cap drop EPR
gen EPR = 0 if status=="DISCRIMINATED"|status=="POWERLESS"
replace EPR = 1 if status=="JUNIOR PARTNER"|status=="SENIOR PARTNER"	// Junior partys
replace EPR = 2 if status=="MONOPOLY"|status=="DOMINANT"	// Dominating
tab EPR


cap drop InPower Trade_InPower
recode EPR (0 1 = 0) (2 = 1) , gen(InPower)

gen Trade_InPower = Trade_Exposure*InPower

bysort country_code: egen max_stat = max(EPR)

gen h = tribe_code if EPR==max_stat
bysort country_code: egen tribe_dest = max(tribe_code)

merge m:1 tribe_code tribe_dest country_code using "$data\Murdock_Dist_Ethnic.dta", keepusing(Distance_To_Tribe)

gen Trade_Dist = Trade_Exposure*Distance_To_Tribe
gen Trade_Change = Trade_Exposure*ln(Distance_To_Tribe+1)

gen lnDist = ln(Distance_To_Tribe+1) if Distance_To_Tribe!=.


eststo clear
qui   {
		
	eststo:  reghdfe Lid Trade_Exposure Trade_Change   , a(country_code##year country_code##tribe_code ) cl(country_code) tol(1e-4)

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		su Lid if e(sample)
		estadd scalar MEAN `r(mean)'		
		
	eststo:  reghdfe Lid Trade_Exposure Trade_Change Trade_InPower  , a(country_code##year##InPower country_code##tribe_code ) cl(country_code) tol(1e-4)

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		su Lid if e(sample)
		estadd scalar MEAN `r(mean)'			
}

esttab, drop(_cons  ) star(* 0.1 ** 0.05 *** 0.01)  stat(countryyear Ethniccountry MEAN N )


*** USE NTL

tempfile temp 
import delimited using "$data/african_countries_iso_codes.csv", clear
rename iso_a3 iso3
rename iso_n3 country_code
save `temp', replace

import delimited using "$data/worldcities.csv", clear

rename lat city_lat
rename lng city_lon

keep if capital=="primary"
keep iso3 city_ascii city_lat city_lon

duplicates drop iso3, force

merge 1:1 iso3 using `temp', keepusing(country_code)
keep if _merge==3
drop _merge

merge 1:m country_code using  "$data/NTL_Trade_Data.dta"

drop _merge


save `temp', replace

use "$data/Murdock.dta", clear
duplicates drop country_code tribe_code, force

keep country_code tribe_code ethnic_centroid_X ethnic_centroid_Y
merge 1:m country_code tribe_code  using `temp'

drop _merge

geodist city_lat city_lon ethnic_centroid_X ethnic_centroid_Y, gen(Dist_tribe_city)

su Dist_*
gen lnDist_Tribe = log(Dist_tribe_city)

cap drop Trade_Expos*
gen Trade_Exposure = lnExport*popshare_tribe

tab status
cap drop EPR
gen EPR = 0 if status=="DISCRIMINATED"|status=="POWERLESS"
replace EPR = 1 if status=="JUNIOR PARTNER"|status=="SENIOR PARTNER"	// Junior partys
replace EPR = 2 if status=="MONOPOLY"|status=="DOMINANT"	// Dominating
tab EPR


cap drop InPower Trade_InPower
recode EPR (0 1 = 0) (2 = 1) , gen(InPower)

gen Trade_InPower = Trade_Exposure*InPower

gen Trade_Change = Trade_Exposure*lnDist_Tribe





qui   {
		
	eststo:  reghdfe Lid Trade_Exposure Trade_Change   , a(country_code##year country_code##tribe_code ) cl(country_code) tol(1e-4)

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		su Lid if e(sample)
		estadd scalar MEAN `r(mean)'		
	eststo:  reghdfe Lid Trade_Exposure Trade_Change Trade_InPower  , a(country_code##year##InPower country_code##tribe_code ) cl(country_code) tol(1e-4)

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		su Lid if e(sample)
		estadd scalar MEAN `r(mean)'		
	
	
}

esttab, drop(_cons  ) star(* 0.1 ** 0.05 *** 0.01)  stat(countryyear Ethniccountry MEAN N )

	

use "$data/NTL_Trade_Data.dta", clear

cap drop Trade_Expos*
gen Trade_Exposure = lnExport*popshare_tribe

tab status
cap drop EPR
gen EPR = 0 if status=="DISCRIMINATED"|status=="POWERLESS"
replace EPR = 1 if status=="JUNIOR PARTNER"|status=="SENIOR PARTNER"	// Junior partys
replace EPR = 2 if status=="MONOPOLY"|status=="DOMINANT"	// Dominating
tab EPR


cap drop InPower Trade_InPower
recode EPR (0 1 = 0) (2 = 1) , gen(InPower)
gen Trade_InPower = Trade_Exposure*InPower
keep if Lid!=.


merge m:1 country_code tribe_code using "$data/Caloric_Change.dta",

drop _merge

gen Change = (Change_Mean_Ave)/(Std_Pre_Ave) // if Change_Mean_Ave!=0

local var = "Change"
cap drop Trade_Cha*
gen Trade_Change= lnExport*`var' 




qui   {
		
	eststo:  reghdfe Lid Trade_Exposure Trade_Change , a(country_code##year country_code##tribe_code ) cl(country_code#tribe_code) tol(1e-4)

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		su Lid if e(sample)
		estadd scalar MEAN `r(mean)'		
	eststo:  reghdfe Lid Trade_Exposure Trade_Change Trade_InPower   , a(country_code##year##InPower country_code##tribe_code ) cl(country_code#tribe_code) tol(1e-4)

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		su Lid if e(sample)
		estadd scalar MEAN `r(mean)'		
}

esttab, drop(_cons  ) order(Trade_Exposure Trade_Change Trade_InPower ) star(* 0.1 ** 0.05 *** 0.01)  stat(countryyear Ethniccountry MEAN N ) b(%9.3f)

esttab using "$tables/T4_Heterogeneity.tex" ///
	, replace booktabs fragment ///
	order(Trade_Exposure Trade_Change Trade_InPower ) ///
	drop(_cons ) cells(b(fmt(%9.3f) star  label(" ")) se(par label(" ") ))   ///
	star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
	coeflabel(	Trade_Exposure "Trade Exposure" Trade_InPower "Trade Exposure \(\times\) In Power" ///
				Trade_Change "Trade  \(\times\) Heterogeneity") ///
	nomtitles nonumbers nodepvars noobs nonote nogaps noline ///
	substitute(\_ _ / ) 
	
********************************************************************************
***  Main Figure 1 (Instrument)
********************************************************************************	
	
use "$data\Trade_Data.dta", clear



reghdfe lnExport lnMS_SM $pair Linguistic_Similarity Genetic_Similarity if border_n==1 , cluster(dest_code country_code) a(dest_code##year country_code##year) keepsingletons 


local b : di %5.3f  _b[lnMS_SM]
local se : di %5.3f  _se[lnMS_SM]
local F : di %4.2f  (_b[lnMS_SM]/_se[lnMS_SM])^2
di "`b' (`se'), F-stat: `F'"

cap drop yhat xhat
reghdfe lnExport $pair Linguistic_Similarity Genetic_Similarity if border_n==1 , cluster(dest_code country_code) a(dest_code##year country_code##year) keepsingletons resid(yhat)
reghdfe lnMS_SM $pair Linguistic_Similarity Genetic_Similarity if border_n==1 , cluster(dest_code country_code) a(dest_code##year country_code##year) keepsingletons resid(xhat)

binscatter yhat xhat, /// 
	xtitle("Size of cross-border network") ///
	ytitle("Cross-border trade flows") ///
	title("First-stage cross-border trade flows") ///
	note("Point estimate including controls: `b' (`se'), F-stat: `F'")

graph save "$figures/g1.gph", replace



*** At the bilateral level:
use "$data\Trade_Data.dta", clear



*** Search and Matching _ at Border
cap drop resid
reghdfe lnExport lnMS_SM  $pair  Linguistic_Similarity Genetic_Similarity   if border_n==1, cluster(dest_code country_code) a(dest_code##year country_code##year, savefe) keepsingletons  resid(resid)
predict OLS_SM_Border if e(sample), xbd




replace OLS_SM_Border = exp(OLS_SM_Border)




tab country_code
mat LOO = J(`r(r)',2,.)
keep if year>=1990

levelsof country_code, local(clist)
levelsof year, local(ylist)
cap drop Export_loo
gen Export_loo = .
gen Export_loo_nonborder = .
local n = 0
foreach c of local clist {
	local ++n
	di `c'
	mat LOO[`n',1] = `c'
	qui foreach y of local ylist {
		
		cap drop nonborder
		gen nonborder = 1
		replace nonborder = 0 if country_code==`c'|dest_code==`c'
		levelsof dest_code if country_code==`c'&border_n==1, local(dlist)
			foreach d of local dlist {
			    replace nonborder = 0 if country_code==`d'|dest_code==`d'
			}
		sum Export if country_code!=`c'&dest_code!=`c'&year==`y'&nonborder==1
		replace Export_loo = `r(mean)' if Export!=.&country_code==`c'&year==`y'
		sum nonborder 
		mat LOO[`n',2] = `r(mean)'
		cap drop nonborder
		gen nonborder = 1
		replace nonborder = 0 if country_code==`c'
		levelsof dest_code if country_code==`c'&border_n==1, local(dlist)
			foreach d of local dlist {
			    replace nonborder = 0 if country_code==`d'
			}
		sum Export if country_code!=`c'&dest_code!=`c'&year==`y'&nonborder==1
		replace Export_loo_nonborder = `r(mean)' if Export!=.&country_code==`c'&year==`y'
		
	}
}

mat list LOO
svmat LOO 
drop if dyad==.
unique dyad
local d = `r(unique)'
su LOO2
di round(`r(mean)'*`d')

* Calcualte per exports per year:

keep 	country_code dest_code country_isocode year ///
		OLS_*  Export Export_loo Export_loo_nonborder


collapse (sum)  OLS_* Export Export_loo Export_loo_nonborder, by(country_code year)
	
gen lnOLS_SM_Border = log(OLS_SM_Border)
gen lnExport = log(Export)
gen lnExport_loo = log(Export_loo)
gen lnExport_loo2 = log(Export_loo_nonborder)



* Predicted values
la var lnOLS_SM_Border 	"log Predicted Exports, OLS, SM, Border"

* Realized values
la var lnExport 		"log Realized Exports"
la var lnExport_loo		"log Realized Exports of non-bordering countries"

keep ln* country_code year

qui reghdfe lnExport lnOLS_SM_Border , cluster(country_code) a(country_code year) keepsingletons 
test lnOLS_SM_Border
qui reghdfe lnExport lnExport_loo , cluster(country_code) a(country_code year) keepsingletons 
test lnExport_loo
qui reghdfe lnExport lnExport_loo2 , cluster(country_code) a(country_code year) keepsingletons 
test lnExport_loo2

reghdfe lnExport lnOLS_SM_Border , cluster(country_code) a(country_code year) keepsingletons 

local b : di %5.3f  _b[lnOLS_SM_Border]
local se : di %5.3f  _se[lnOLS_SM_Border]
local F : di %4.2f  (_b[lnOLS_SM_Border]/_se[lnOLS_SM_Border])^2
di "`b' (`se'), F-stat: `F'"



cap drop yhat xhat 
reghdfe lnExport  , cluster(country_code) a(country_code year) keepsingletons  resid(yhat)
reghdfe lnOLS_SM_Border , cluster(country_code) a(country_code year) keepsingletons  resid(xhat)

binscatter yhat xhat, n(100) ///
	xtitle("Predicted trade flows with neighboring countries") ///
	ytitle("Realized trade flows with all countries") ///
	title("Cross-border instrument") ///
	note("Point estimate:  `b' (`se'), F-stat: `F'")
	
graph save "$figures/g2a.gph", replace



reghdfe lnExport lnExport_loo , cluster(country_code) a(country_code year) keepsingletons 

local b : di %5.3f  _b[lnExport_loo]
local se : di %5.3f  _se[lnExport_loo]
local F : di %4.2f  (_b[lnExport_loo]/_se[lnExport_loo])^2
di "`b' (`se'), F-stat: `F'"
local n = round(e(N)/10)
di `n'

cap drop yhat xhat 
reghdfe lnExport  , cluster(country_code) a(country_code year) keepsingletons  resid(yhat)
reghdfe lnExport_loo , cluster(country_code) a(country_code year) keepsingletons  resid(xhat)

binscatter yhat xhat, n(100) ///
	xtitle("Predicted trade flows with all countries") ///
	ytitle("Realized trade flows with all countries") ///
	title("Leave-one-out instrument") ///
	note("Point estimate:  `b' (`se'), F-stat: `F'")
	
graph save "$figures/g2b.gph", replace


graph combine "$figures/g2a.gph" "$figures/g2b.gph", row(1)  iscale(0.75) ysize(1) xsize(2)

graph export "$figures/Instrument.png", replace width(2000) as(png)

eststo clear
qui eststo: reghdfe lnExport_loo lnOLS_SM_Border, cluster(country_code) a(country_code year) 
test lnOLS_SM_Border
qui eststo: reghdfe lnExport lnExport_loo lnOLS_SM_Border, cluster(country_code) a(country_code year) 
esttab, stat(r2_within) se
	
********************************************************************************
***  Table 5 (IV Results)
********************************************************************************		
	

use "$data/NTL_Trade_Data.dta", clear

* Dependent Variable
cap drop Trade_Expos*
gen Trade_Exposure = lnExport*popshare_tribe


* Political variable
tab status
cap drop EPR
gen EPR = 0 if status=="DISCRIMINATED"|status=="POWERLESS"|status=="IRRELEVANT"|status=="STATE COLLAPSE"
replace EPR = 1 if status=="JUNIOR PARTNER"|status=="SENIOR PARTNER"	// Junior partys
replace EPR = 2 if status=="MONOPOLY"|status=="DOMINANT"	// Dominating
tab EPR

cap drop InPower Trade_InPower
recode EPR (0 1 = 0) (2 = 1) , gen(InPower)

* Interaction
gen Trade_InPower = Trade_Exposure*InPower


* Cluster:
gen cXe = country_code*1000+tribe_code

*** OLS Instrument:

foreach var of varlist Lid lnNTL   {
qui {
	eststo clear
	eststo: ivreghdfe `var' Trade_Exposure , a(country_code##year country_code##tribe_code ) cl(cXe) 

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		
	
	eststo: reghdfe `var' Trade_Exposure Trade_InPower , a(country_code##year##InPower country_code##tribe_code ) cl(cXe) 

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		estadd local reduced ""
		
	foreach dvar of varlist lnOLS_SM_Border  lnExport_loo {
    
		cap drop Trade_IV_Power
		cap drop Trade_IV_Exposure
		gen Trade_IV_Exposure = `dvar'*popshare_tribe
		gen Trade_IV_Power = Trade_IV_Exposure*InPower

	eststo: ivreghdfe `var' (Trade_Exposure=Trade_IV_Exposure) , a(country_code##year country_code##tribe_code ) cl(cXe) 

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		
	
	eststo: reghdfe `var' Trade_IV_Exposure Trade_IV_Power , a(country_code##year##InPower country_code##tribe_code ) cl(cXe) 

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		estadd local reduced "Yes"
		
	}
}
esttab, drop(_cons  ) star(* 0.1 ** 0.05 *** 0.01)  stat(countryyear Ethniccountry reduced rkf N)

esttab  using "$tables/T5_IV_`var'.tex" ///
		, replace booktabs fragment ///
		keep(Trade_*) cells(b(fmt(%9.3f) star  label(" ")) se(par label(" ") ))   ///
		star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
		coeflabel(Trade_Exposure "Trade Exposure" Trade_InPower "Trade Exposure \(\times\) In Power" Trade_IV_Exposure "Predicted Trade Exposure" Trade_IV_Power  "Predicted Trade Exposure \(\times\) In Power") ///
		nomtitles nonumbers nodepvars noobs nonote nogaps noline ///
		substitute(\_ _ / ) 
		
// bring panels together
	#delimit ;
	esttab using "$tables/M5_IV_Panel_`var'.tex", replace booktabs
		cells(none) nonote noobs mtitles("OLS" "OLS" "IV" "RF" "IV" "RF") ///
		mgroups("OLS" "Cross-Border" "Leave-One-Out", pattern(1 0 1 0 1 0  ) 
		prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
		prefoot(  
		\panelinput{"$tables/T5_IV_`var'.tex"} 
		\\
		\midrule )
		substitute(\_ _)	
	stats( countryyear Ethniccountry reduced N rkf , ///
		label("Country \(\times\) year fixed effects" "Country \(\times\) ethnicity fixed effects" "Reduced form" "Observations" "First Stage F-Test") fmt(a a a %9.0fc %9.3f  )) 
	;
	#delimit cr	
		
}

// bring panels together
	#delimit ;
	esttab using "$tables/M5_IV_Panel.tex", replace booktabs
		cells(none) nonote noobs mtitles("OLS" "OLS" "IV" "RF" "IV" "RF") ///
		mgroups("OLS" "Cross-Border" "Leave-One-Out", pattern(1 0 1 0 1 0  ) 
		prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
		prefoot(  
		\multicolumn{@span}{l}{\emph{Panel A: Fraction of pixel lit }} \\ 
		\panelinput{"$tables/T5_IV_Lid.tex"} 
		\midrule \multicolumn{@span}{l}{\emph{Panel B: Average nighttime luminosity}} \\ 
		\panelinput{"$tables/T5_IV_lnNTL.tex"} 
		\midrule )
		substitute(\_ _)	
	stats( countryyear Ethniccountry reduced N rkf , ///
		label("Country \(\times\) year fixed effects" "Country \(\times\) ethnicity fixed effects" "Reduced form" "Observations" "First Stage F-Test") fmt(a a a %9.0fc %9.3f  )) 
	;
	#delimit cr	
		

********************************************************************************
***  Table 6 (IV Results)
********************************************************************************			

use "$data/Afrobarometer_Trade.dta", clear

* Dependent Variable
cap drop Trade_Expos*
gen Trade_Exposure = lnExport*popshare_tribe
gen Trade_Exposure_OLS = lnOLS_EN_Border*popshare_tribe
gen Trade_Exposure_PPML = lnPPML_EN_Border*popshare_tribe

* Political variable

cap drop EPR
gen EPR = 0 if status=="DISCRIMINATED"|status=="POWERLESS"|status=="IRRELEVANT"|status=="STATE COLLAPSE"
replace EPR = 1 if status=="JUNIOR PARTNER"|status=="SENIOR PARTNER"	// Junior partys
replace EPR = 2 if status=="MONOPOLY"|status=="DOMINANT"	// Dominating
tab EPR

cap drop InPower Trade_InPower
recode EPR (0 1 = 0) (2 = 1) , gen(InPower)

* Interaction
gen Trade_InPower = Trade_Exposure*InPower
gen Trade_OLS_InPower = Trade_Exposure_OLS*InPower
gen Trade_PPML_InPower = Trade_Exposure_PPML*InPower

*cluster
gen cXe = country_code*1000+tribe_code

*** OLS Instrument:


 foreach var of varlist z_Household z_Democracy z_Trust {
eststo clear
 qui {

			
	eststo: reghdfe `var' Trade_Exposure , a(country_code##year country_code##tribe_code Age Male Education Urban) cl(cXe) 

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"					
		estadd local ind 	"Yes"			
		
	eststo: reghdfe `var' Trade_Exposure Trade_InPower, a(country_code##year##InPower country_code##tribe_code Age Male Education Urban) cl(country_code#tribe_code) tol(1e-4)

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"					
		estadd local ind 	"Yes"		
		estadd local reduced ""
		
	foreach dvar of varlist lnOLS_SM_Border lnExport_loo {
    
		cap drop Trade_IV_Power
		cap drop Trade_IV_Exposure
		gen Trade_IV_Exposure = `dvar'*popshare_tribe
		gen Trade_IV_Power = Trade_IV_Exposure*InPower

	eststo: ivreghdfe `var' (Trade_Exposure=Trade_IV_Exposure) , a(country_code##year##InPower country_code##tribe_code Age Male Education Urban)  cl(cXe)  

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		estadd local ind 	"Yes"
		
	
	eststo: reghdfe `var' Trade_IV_Exposure Trade_IV_Power , a(country_code##year##InPower country_code##tribe_code Age Male Education Urban)  cl(cXe)  

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		estadd local ind 	"Yes"
		estadd local reduced "Yes"
		
	}
	
}

esttab, drop(_cons  ) star(* 0.1 ** 0.05 *** 0.01)  stat(countryyear Ethniccountry ind N rkf) 	

esttab  using "$tables/T6_IV_`var'.tex" ///
		, replace booktabs fragment ///
		keep(Trade_*) cells(b(fmt(%9.3f) star  label(" ")) se(par label(" ") ))   ///
		star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
		coeflabel(Trade_Exposure "Trade Exposure" Trade_InPower "Trade Exposure \(\times\) In Power" Trade_IV_Exposure "Predicted Trade Exposure" Trade_IV_Power  "Predicted Trade Exposure \(\times\) In Power") ///
		nomtitles nonumbers nodepvars noobs nonote nogaps noline ///
		substitute(\_ _ / ) 
		
// bring panels together
	#delimit ;
	esttab using "$tables/M6_IV_Panel_`var'.tex", replace booktabs
		cells(none) nonote noobs mtitles("OLS" "OLS" "IV" "RF" "IV" "RF") ///
		mgroups("OLS" "Cross-Border" "Leave-One-Out", pattern(1 0 1 0 1 0  ) 
		prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
		prefoot(  
		\panelinput{"$tables/T6_IV_`var'.tex"} 
		\\
		\midrule )
		substitute(\_ _)	
	stats( countryyear Ethniccountry ind reduced N rkf , ///
		label("Country \(\times\) year fixed effects" "Country \(\times\) ethnicity fixed effects" "Individual controls" "Reduced form" "Observations" "First Stage F-Test") fmt(a a a a %9.0fc %9.3f  )) 
	;
	#delimit cr	

}


// bring panels together
	#delimit ;
	esttab using "$tables/M6_AB_Panel.tex", replace booktabs
		cells(none) nonote noobs mtitles("OLS" "OLS" "IV" "RF" "IV" "RF") ///
		mgroups("OLS" "Cross-Border" "Leave-One-Out", pattern(1 0 1 0 1 0  ) 
		prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
		prefoot(  
		\multicolumn{@span}{l}{\emph{Panel A: Household Wealth }} \\ 
		\panelinput{"$tables/T6_IV_z_Household.tex"} 
		\midrule \multicolumn{@span}{l}{\emph{Panel B: Satisfaction with Democracy}} \\ 
		\panelinput{"$tables/T6_IV_z_Democracy.tex"} 
		\midrule \multicolumn{@span}{l}{\emph{Panel C: Trust in Institutions}} \\ 
		\panelinput{"$tables/T6_IV_z_Trust.tex"} 
		\midrule )
		substitute(\_ _)	
	stats( countryyear Ethniccountry ind reduced N rkf , ///
		label("Country \(\times\) year fixed effects" "Country \(\times\) ethnicity fixed effects" "Individual controls" "Reduced form" "Observations" "First Stage F-Test") fmt(a a a a %9.0fc %9.3f  )) 
	;
	#delimit cr	
		

		
exit 

