*** Use Control find "B6" or title of table to find code
*** Afrobarometer code cannot be run unless dataaccess has been granted by
/*
BenYishay, A., Rotberg, R., Wells, J., Lv, Z., Goodman, S., Kovacevic, L., Runfola, D. 2017. 
Geocoding Afrobarometer Rounds 1 – 6: Methodology & Data Quality. AidData. Available online at http://geo.aiddata.org.
*/

********************************************************************************
*** Appendix A : Supporting Evidence
********************************************************************************				
		
*** Coefficient Stability

use "$data/NTL_Trade_Data.dta", clear

cap drop Trade_Expos*
gen Trade_Exposure = lnExport*popshare_tribe

tab status
cap drop EPR
gen EPR = 0 if status=="DISCRIMINATED"|status=="POWERLESS"
replace EPR = 1 if status=="JUNIOR PARTNER"|status=="SENIOR PARTNER"	// Junior partys
replace EPR = 2 if status=="MONOPOLY"|status=="DOMINANT"	// Dominating
tab EPR


cap drop InPower Trade_InPower
recode EPR (0 1 = 0) (2 = 1) , gen(InPower)

gen Trade_InPower = Trade_Exposure*InPower


qui reghdfe Lid Trade_Exposure Trade_InPower , a(country_code##year##InPower country_code##tribe_code ) cl(country_code#tribe_code) tol(1e-4)
	local lid = _b[Trade_Exposure]	
	local lidint = _b[Trade_Exposure]	

	di "Lid: "  %5.3f `lid' 
	di "Lid in Power: "  %5.3f `lidint' 
	
qui reghdfe lnNTL Trade_Exposure Trade_InPower , a(country_code##year##InPower country_code##tribe_code ) cl(country_code#tribe_code) tol(1e-4)
	local ntl = _b[Trade_Exposure]	
	local ntlint = _b[Trade_Exposure]	

	di "NTL: "  %5.3f `ntl' 
	di "NTL in Power: "  %5.3f `ntlint' 	

levelsof country_code, local(clist)
local m : list sizeof local(clist)	
di `m'
mat Z = J(`m'+1,5,.)


local n = 1



mat Z[1,1] = 1
mat Z[1,2] = `lid'
mat Z[1,3] = `lidint'
mat Z[1,4] = `ntl'
mat Z[1,5] = `ntlint'


qui foreach c of local clist {
	local n = `n'+1
	matrix Z[`n',1] = `c'
	reghdfe Lid Trade_Exposure Trade_InPower if country_code!=`c' , a(country_code##year##InPower country_code##tribe_code ) cl(country_code#tribe_code) tol(1e-4)
	matrix Z[`n',2] = _b[Trade_Exposure]/abs(`lid')
	matrix Z[`n',3] = _b[Trade_InPower]/abs(`lidint')
	
	
	
	reghdfe lnNTL Trade_Exposure Trade_InPower if country_code!=`c' , a(country_code##year##InPower country_code##tribe_code ) cl(country_code#tribe_code) tol(1e-4)
	matrix Z[`n',4] = _b[Trade_Exposure]/abs(`ntl')	
	matrix Z[`n',5] = _b[Trade_InPower]/abs(`ntlint')
		
}



preserve
	cap drop Z1-Z5
	svmat Z

	
	
	#delimit ;
		 twoway (hist Z2 if Z1!=1, fraction gap(5)  bin(`m')) , ///
		 xtitle("") ytitle("") ///
		 legend(off) xlabel(-1.5(0.5)1.5) title("Fraction Lit");
	#delimit cr
	graph save "$figures\LeaveOneOut_Lid.gph", replace	

	#delimit ;
		 twoway (hist Z3 if Z1!=1, fraction gap(5)  bin(`m')) , ///
		 xtitle("") ytitle("") ///
		 legend(off) xlabel(-1.5(0.5)1.5) title("Fraction Lit, in Power");
	#delimit cr
	graph save "$figures\LeaveOneOut_Lidint.gph", replace		
	
	#delimit ;
		 twoway (hist Z4 if Z1!=1, fraction gap(5)  bin(`m')) , ///
		 xtitle("") ytitle("") ///
		 legend(off) xlabel(-1.5(0.5)1.5) title("Average luminosity");
	#delimit cr
	graph save "$figures\LeaveOneOut_NTL.gph", replace		
	
	#delimit ;
		 twoway (hist Z5 if Z1!=1, fraction gap(5)  bin(`m')) , ///
		 xtitle("") ytitle("") ///
		 legend(off) xlabel(-1.5(0.5)1.5) title("Average luminosity, in Power");
	#delimit cr
	graph save "$figures\LeaveOneOut_NTLint.gph", replace		

restore	


*** Afrobarometer

use "$data/Afrobarometer_Trade.dta", clear

* Dependent Variable
cap drop Trade_Expos*
gen Trade_Exposure = lnExport*popshare_tribe

* Political variable

cap drop EPR
gen EPR = 0 if status=="DISCRIMINATED"|status=="POWERLESS"|status=="IRRELEVANT"|status=="STATE COLLAPSE"
replace EPR = 1 if status=="JUNIOR PARTNER"|status=="SENIOR PARTNER"	// Junior partys
replace EPR = 2 if status=="MONOPOLY"|status=="DOMINANT"	// Dominating
tab EPR

cap drop InPower Trade_InPower
recode EPR (0 1 = 0) (2 = 1) , gen(InPower)

* Interaction
gen Trade_InPower = Trade_Exposure*InPower

qui reghdfe z_Household Trade_Exposure Trade_InPower, a(country_code##year##InPower country_code##tribe_code Age Male Education Urban) cl(country_code#tribe_code) tol(1e-4)
	local ae = _b[Trade_Exposure]
	di "Average Effect: "  %5.3f `ae' 
	local int = _b[Trade_InPower]
	di "Interaction: "  %5.3f `int' 	
	


levelsof country_code, local(clist)
local m : list sizeof local(clist)	
di `m'
mat Z = J(`m'+1,3,.)


local n = 1



mat Z[1,1] = 1
mat Z[1,2] = `ae'
mat Z[1,3] = `int'


qui foreach c of local clist {
	local n = `n'+1
	matrix Z[`n',1] = `c'
	reghdfe z_Household Trade_Exposure Trade_InPower if country_code!=`c', a(country_code##year##InPower country_code##tribe_code Age Male Education Urban) cl(country_code#tribe_code) tol(1e-4)
	matrix Z[`n',2] = _b[Trade_Exposure]/abs(`ae')
	matrix Z[`n',3] = _b[Trade_InPower]/abs(`int')

		
}



preserve
	cap drop Z1-Z3
	svmat Z

	
	
	#delimit ;
		 twoway (hist Z2 if Z1!=1, fraction gap(5)  bin(`m') ) , ///
		 xtitle("") ytitle("") ///
		 legend(off) xlabel(-1.5(0.5)1.5) title("Welfare");
	#delimit cr
	graph save "$figures\LeaveOneOut_Household.gph", replace	
	
	#delimit ;
		 twoway (hist Z3 if Z1!=1, fraction gap(5) bin(`m'))  , ///
		 xtitle("") ytitle("") ///
		 legend(off) xlabel(-1.5(0.5)1.5) title("Welfare, In Power");
	#delimit cr
	graph save "$figures\LeaveOneOut_Householdint.gph", replace	
	

restore	

graph combine 	"$figures\LeaveOneOut_Lid.gph" "$figures\LeaveOneOut_NTL.gph" "$figures\LeaveOneOut_Household.gph"  ///
				"$figures\LeaveOneOut_Lidint.gph" "$figures\LeaveOneOut_NTLint.gph" "$figures\LeaveOneOut_Householdint.gph" , ///
	ycommon  title("Coefficient stability") iscale(0.75) xsize(2) ysize(1)
	
graph export "$figures\Coefficient_Stability.png", replace as(png) width(2000)
	
	

		
***  Sectoral Exports


use "$data/NTL_Trade_Data.dta", clear

cap drop Trade_Expos*
gen Trade_Exposure = lnExport*popshare_tribe
gen Trade_Exposure_OLS = lnOLS_SM_Border*popshare_tribe

gen Manufacturing_Exposure = lnManufacturing*popshare_tribe
gen Manufacturing_Exposure_OLS = lnOLSManufacturing*popshare_tribe

gen Agriculture_Exposure = lnAgriculture*popshare_tribe
gen Agriculture_Exposure_OLS = lnOLSAgriculture*popshare_tribe

gen Resources_Exposure = lnResources*popshare_tribe
gen Resources_Exposure_OLS = lnOLSResources*popshare_tribe





eststo clear
qui foreach var of varlist Lid lnNTL {
		
	eststo: reghdfe `var' c.Trade_Exposure , a(country_code##year country_code##tribe_code ) cl(country_code#tribe_code) tol(1e-4)

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		
	
	eststo: reghdfe `var' c.Manufacturing_Exposure , a(country_code##year country_code##tribe_code ) cl(country_code#tribe_code) tol(1e-4)

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		
	
		
	eststo: reghdfe `var' c.Agriculture_Exposure , a(country_code##year country_code##tribe_code ) cl(country_code#tribe_code) tol(1e-4)

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
	
		
		
	eststo: reghdfe `var' c.Resources_Exposure , a(country_code##year country_code##tribe_code ) cl(country_code#tribe_code) tol(1e-4)

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		

				
	
}

esttab, drop(_cons  ) star(* 0.1 ** 0.05 *** 0.01)  stat(countryyear Ethniccountry N)



esttab  using "$tables/A1_NTL.tex" ///
		, replace booktabs fragment ///
		keep(Trade_Exposure Manufacturing_Exposure Agriculture_Exposure Resources_Exposure  ) cells(b(fmt(%9.3f) star  label(" ")) se(par label(" ") ))   ///
		star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
		coeflabel(Trade_Exposure "Trade Exposure" Manufacturing_Exposure "Exposure to manufacturing exports" ///
				Agriculture_Exposure "Exposure to agriculture exports" Resources_Exposure "Exposure to resource exports" ) ///
		nomtitles nonumbers nodepvars noobs nonote nogaps noline ///
		substitute(\_ _ / ) 
		
// bring panels together
	#delimit ;
	esttab using "$tables/A1_NTL_Panel.tex", replace booktabs
		cells(none) nonote noobs nomtitles ///
		mgroups("Fraction Lit" "Average luminosity" , pattern(1 0 0 0 1 0 0 0) 
		prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
		prefoot( 
		\panelinput{"$tables/A1_NTL.tex"} 
		\\
		\midrule 
		)
		substitute(\_ _)	
	stats( countryyear Ethniccountry N, ///
		label("Country \(\times\) year fixed effects" "Country \(\times\) ethnicity fixed effects" "Observations") fmt(a a %9.0fc)) 
	;
	#delimit cr		

	

tab status
cap drop EPR
gen EPR = 0 if status=="DISCRIMINATED"|status=="POWERLESS"
replace EPR = 1 if status=="JUNIOR PARTNER"|status=="SENIOR PARTNER"	// Junior partys
replace EPR = 2 if status=="MONOPOLY"|status=="DOMINANT"	// Dominating
tab EPR


cap drop InPower 
recode EPR (0 1 = 0) (2 = 1) , gen(InPower)

cap drop Manu_InPower Agri_InPower
gen Manu_InPower = Manufacturing_Exposure*InPower
gen Agri_InPower = Agriculture_Exposure*InPower
	

eststo clear
foreach dvar of varlist lnManufacturing lnAgriculture {

	cap drop Trade_Exposure 
	cap drop Trade_InPower 
	gen Trade_Exposure = `dvar'*popshare_tribe
	gen Trade_InPower = Trade_Exposure*InPower
	qui foreach var of varlist Lid lnNTL {

		eststo: reghdfe `var' Trade_Exposure Trade_InPower, a(country_code##year##InPower country_code##tribe_code ) cl(country_code#tribe_code) tol(1e-4)

			estadd local countryyear 	"Yes"
			estadd local Ethniccountry 	"Yes"	
	}
	
				

				
	
}

esttab, drop(_cons  ) star(* 0.1 ** 0.05 *** 0.01)  stat(countryyear Ethniccountry N)



esttab  using "$tables/A1_NTLb.tex" ///
		, replace booktabs fragment ///
		keep(Trade_Exposure Trade_InPower  ) cells(b(fmt(%9.3f) star  label(" ")) se(par label(" ") ))   ///
		star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
		coeflabel(Trade_Exposure "Trade Exposure" Trade_InPower "Trade Exposure \(\times\) In Power" ) ///
		nomtitles nonumbers nodepvars noobs nonote nogaps noline ///
		substitute(\_ _ / ) 
		
// bring panels together
	#delimit ;
	esttab using "$tables/A1_NTL_Panelb.tex", replace booktabs
		cells(none) nonote noobs ///
		mtitles("Lit" "Ave. Lum." "Lit" "Ave. Lum.") ///
		mgroups("Manufacturing Exports" "Agricultural Exports" , pattern(1 0 1  0) 
		prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
		prefoot( 
		\panelinput{"$tables/A1_NTLb.tex"} 
		\\
		\midrule 
		)
		substitute(\_ _)	
	stats( countryyear Ethniccountry N, ///
		label("Country \(\times\) year fixed effects" "Country \(\times\) ethnicity fixed effects" "Observations") fmt(a a %9.0fc)) 
	;
	#delimit cr		

	
	
	
********************************************************************************
***  Section A.1: Derrivation of Main equation
********************************************************************************	

use "$data/NTL_Trade_Data.dta", clear

cap drop Trade_Expos*
gen Trade_Exposure = lnExport*popshare_tribe
gen Trade_Exposure_OLS = lnOLS_SM_Border*popshare_tribe
gen Trade_Exposure_PPML = lnPPML_SM_Border*popshare_tribe

la var Trade_Exposure  "Trade Exposure"

gen lnGDP_pc = log(GDPpc)
la var lnGDP_pc "log(GDP per capita)"

foreach var of varlist Lid {
eststo clear
qui  {

	eststo: reghdfe `var' lnExport popshare_tribe lnGDP_pc , a(country_code year ) cl(country_code#tribe_code) tol(1e-4)
		estadd local country 		"yes"
		estadd local year 			"yes"
		estadd local countryyear 	""
		estadd local tribe_code		""
		estadd local Ethniccountry 	""	
		su Lid if e(sample)
		estadd scalar MEAN `r(mean)'
		
	eststo: reghdfe `var' Trade_Exposure lnExport popshare_tribe lnGDP_pc , a(country_code year ) cl(country_code#tribe_code) tol(1e-4)

		estadd local country 		"yes"
		estadd local year 			"yes"
		estadd local countryyear 	""
		estadd local tribe_code		""
		estadd local Ethniccountry 	""	
		su Lid if e(sample)
		estadd scalar MEAN `r(mean)'
		
	eststo: reghdfe `var' Trade_Exposure lnExport popshare_tribe lnGDP_pc , a(country_code year tribe_code) cl(country_code#tribe_code) tol(1e-4)

		estadd local country 		"yes"
		estadd local year 			"yes"
		estadd local countryyear 	""
		estadd local tribe_code		"yes"
		estadd local Ethniccountry 	""	
		su Lid if e(sample)
		estadd scalar MEAN `r(mean)'		

	eststo: reghdfe `var' Trade_Exposure  popshare_tribe  , a(country_code##year tribe_code) cl(country_code#tribe_code) tol(1e-4)

		estadd local country 		"yes"
		estadd local year 			"yes"
		estadd local countryyear 	"yes"
		estadd local tribe_code		"yes"
		estadd local Ethniccountry 	""	
		su Lid if e(sample)
		estadd scalar MEAN `r(mean)'				
		
		
		
	eststo: reghdfe `var' Trade_Exposure , a(country_code##year country_code##tribe_code ) cl(country_code#tribe_code) tol(1e-4)

		estadd local country 		"yes"
		estadd local year 			"yes"
		estadd local countryyear 	"yes"
		estadd local tribe_code		"yes"
		estadd local Ethniccountry 	"yes"	
		su Lid if e(sample)
		estadd scalar MEAN `r(mean)'
		
	
	
}

esttab, drop(_cons  ) order(Trade_Exposure) star(* 0.1 ** 0.05 *** 0.01)  /// 
		stat(country year tribe_code countryyear Ethniccountry MEAN r2_a N , fmt(a a a a a  %9.3f %9.3f  %9.0fc))

}
	
esttab  using "$tables/T1_NTL_Appendix_A1.tex" ///
		, replace booktabs fragment ///
		drop(_cons) order(Trade_Exposure)  cells(b(fmt(%9.3f) star  label(" ")) se(par label(" ") ))   ///
		star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
		label ///
		nomtitles nonumbers nodepvars noobs nonote nogaps noline ///
		substitute(\_ _ / ) 
		
// bring panels together
	#delimit ;
	esttab using "$tables/M1_NTL_Panel_Appendix_A1.tex", replace booktabs
		cells(none) nonote noobs nomtitles ///
		mgroups("Fraction Lit" , pattern(1 0 0 0 0   ) 
		prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
		prefoot( 
		\panelinput{"$tables/T1_NTL_Appendix_A1.tex"} 
		\\
		\midrule 
		)
		substitute(\_ _)	
	stat(country year tribe_code countryyear Ethniccountry MEAN r2_a N ,
		label("Country fixed effect" "Year fixed effect" "Ethnicity fixed effect" "Country \(\times\) year fixed effects" "Country \(\times\) ethnicity fixed effect" "Mean dependent variable" "Adjusted R2" "Observations" ) fmt(a a a a a  %9.3f %9.3f  %9.0fc)) 
	;
	#delimit cr		
	
	

********************************************************************************
*** Appendix B : Cross Border Instrument
********************************************************************************	
	

use "$data/Murdock_Ethnic", clear

bysort tribe_code: egen TRIBEPOP = sum(pop_ethnic_1960)

gen Tribe_Split = (tribe_number_countries>1)
collapse Tribe_Split tribe_area tribe_number_countries TRIBEPOP LAT LON , by(murdock_name tribe_code)

cap drop $xy lnTP lnTA lnPopdens
gen X = LON
gen Y = LAT
gen XY = X*Y

global xy X Y XY

gen lnTP = log(TRIBEPOP)
gen lnTA = log(tribe_area)
gen lnPopdens = log(TRIBEPOP/tribe_area)

eststo clear
qui eststo: reg Tribe_Split lnTP $xy, robust
qui eststo: reg Tribe_Split lnTP lnTA $xy, robust
qui eststo: reg Tribe_Split lnPopdens $xy, robust
*qui eststo: reg tribe_number_countries lnTP $xy, robust
*qui eststo: reg tribe_number_countries lnTP lnTA $xy, robust
*qui eststo: reg tribe_number_countries lnPopdens $xy, robust
esttab, keep(lnTP lnTA lnPopdens) 



merge 1:1 murdock_name  using "$data/MiPa_Ancestory.dta"


*keep if _merge==3 

gen Agriculture = (v5>=5)
rename v28 Agriculture_Intensity 

rename centr_tribe Centr_Tribe
rename centr_tribe1 Centr_Tribe1

rename v30 SettlementPatterns 

gen Cities = (SettlementPatterns==7|SettlementPatterns==8)
gen Nomadic = (SettlementPatterns==1|SettlementPatterns==2|SettlementPatterns==3)
replace Cities = . if _merge!=3
replace Nomadic = . if _merge!=3

rename v31 SettlementSizes
replace SettlementSizes = . if _merge!=3 

gen Political_Centralization = gr
la var lnTP "log Population in 1960"
la var lnTA "log Ethnic Area"
la var lnPopdens "log Population Density"
la var Political_Centralization "Political Centralization"

eststo clear
qui eststo: reg Tribe_Split lnTP $xy, robust
qui eststo: reg Tribe_Split lnTP lnTA $xy, robust
qui eststo: reg Tribe_Split lnPopdens $xy, robust
qui eststo: reg Tribe_Split Cities $xy if SettlementPatterns!=0, robust
qui eststo: reg Tribe_Split SettlementSizes $xy, robust
qui eststo: reg Tribe_Split Political_Centralization $xy, robust
qui eststo: reg Tribe_Split Political_Centralization lnPopdens SettlementSizes Cities  $xy, robust
qui eststo: reg Tribe_Split Political_Centralization lnTP lnTA SettlementSizes Cities  $xy, robust

esttab, drop($xy _cons) star(* 0.10 ** 0.05 *** 0.01) ar2
esttab  using "$tables/B1_Murdock.tex" ///
		, replace booktabs fragment ///
		drop($xy _cons)   cells(b(fmt(%9.3f) star  label(" ")) se(par label(" ") ))   ///
		star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
		label ///
		nomtitles nonumbers nodepvars noobs nonote nogaps noline ///
		substitute(\_ _ / ) 
	
	
	


***  B2: Ethnic connections and trade flows: log(Exports) between neighboring countries

use "$data\Trade_Data.dta", clear

foreach var of varlist Export  {
	qui {
	cap drop ln`var'
	gen ln`var'=log(`var')
	eststo clear
	*
* two way clustered se
		reghdfe ln`var' lnMS_SM  $pair  if border_n==1 , cluster(dest_code country_code) a(dest_code##year country_code##year) keepsingletons
		matrix twoway = e(V)
		matrix twoway[1,1] = sqrt(twoway[1,1])
	* Correct "Dyad" cluster
	eststo: reghdfe ln`var' lnMS_SM  $pair  if border_n==1 , cluster(dyad_cluster) a(dest_code##year country_code##year) keepsingletons	
		estadd matrix TW = twoway
		
		estadd local pair = "Yes"
		estadd local timesyear= "Yes"

* two way clustered se
		reghdfe ln`var' lnMS_SM  $pair Linguistic_Similarity Genetic_Similarity if border_n==1 , cluster(dest_code country_code) a(dest_code##year country_code##year) keepsingletons
		matrix twoway = e(V)
		matrix twoway[1,1] = sqrt(twoway[1,1])
	* Correct "Dyad" cluster
	eststo: reghdfe ln`var' lnMS_SM  $pair Linguistic_Similarity Genetic_Similarity if border_n==1 , cluster(dyad_cluster) a(dest_code##year country_code##year) keepsingletons	
		estadd matrix TW = twoway
		
		estadd local pair = "Yes"
		estadd local timesyear= "Yes"
		
		
* two way clustered se
		reghdfe ln`var' lnMS_SM  $pair Linguistic_Similarity Genetic_Similarity  rta $conflict if border_n==1 , cluster(dest_code country_code) a(dest_code##year country_code##year) keepsingletons
		matrix twoway = e(V)
		matrix twoway[1,1] = sqrt(twoway[1,1])
	* Correct "Dyad" cluster
	eststo: reghdfe ln`var' lnMS_SM  $pair Linguistic_Similarity Genetic_Similarity  rta $conflict if border_n==1 , cluster(dyad_cluster) a(dest_code##year country_code##year) keepsingletons	
		estadd matrix TW = twoway
		
		estadd local pair = "Yes"
		estadd local timesyear= "Yes"
		estadd local conflict= "Yes"
		
		
	

	* two way clustered se	
		ppmlhdfe `var' lnMS_SM $pair Linguistic_Similarity Genetic_Similarity  rta $conflict  if border_n==1, cluster(dest_code country_code) a(dest_code##year country_code##year) keepsingletons
		matrix twoway = e(V)
		matrix twoway[1,1] = sqrt(twoway[1,1])
	eststo:	ppmlhdfe `var' lnMS_SM $pair Linguistic_Similarity Genetic_Similarity  rta $conflict if border_n==1, cluster(dyad_cluster) a(dest_code##year country_code##year) keepsingletons
	* Correct "Dyad" Cluster
		estadd matrix TW = twoway
		estadd local pair = "Yes"
		estadd local timesyear= "Yes"
		estadd local conflict= "Yes"
		
	
		


	}
	esttab est*, keep(lnMS_SM  rta $conflict Linguistic_Similarity Genetic_Similarity) cells(b(fmt(%9.3f) star  ) se(par) TW(par([ ])) ) starlevels( * 0.1 ** 0.05 *** 0.01 ) ///
		stats( pair timesyear conflict N, ///
		label("Country-pair controls" "Exporter and importer \(\times\) year fixed effects" "Conflict controls" ) ///
		fmt(a a a %9.0fc )) coeflabel(lnEN "Ethnic connections" Linguistic_Similarity  "Linguistic distance" Genetic_Similarity "Genetic distance" rta "Regional trade agreements" lnConflict "log(\# Conflict)" lnCivillian "log(\# Civilian deaths)" lnDeath "log(\# Deaths)" ) varwidth(35)
			
	esttab using "$tables/B2_`var'.tex" ///
			, replace booktabs fragment ///
			keep(lnMS_SM  rta $conflict Linguistic_Similarity Genetic_Similarity ) cells(b(fmt(%9.3f) star  label(" ")) se(par label(" ") ) TW(par([ ]) label(" ")))   ///
			star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
			coeflabel(lnMS_SM "Ethnic connections" Linguistic_Similarity "Linguistic distance" Genetic_Similarity "Genetic distance" rta "Regional trade agreements" lnConflict "log(\# Conflict)" lnCivillian "log(\# Civilian deaths)" lnDeath "log(\# Deaths)" ) ///
			nomtitles nonumbers nodepvars noobs nonote nogaps noline ///
			substitute(\_ _ / ) 		 			
}			

		// bring panels together
				#delimit ;
				esttab using "$tables/B2_Trade.tex", replace booktabs
					cells(none) nonote noobs nomtitles ///
					mgroups("OLS" "PPML"  , pattern(1 0 0  1  ) 
					prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
					prefoot(
					\panelinput{"$tables/B2_Export.tex"} 
					\\
					\midrule )
					substitute(\_ _)	
				stats( pair timesyear N, ///
					label("Country-pair controls" "Exporter and importer \(\times\) year fixed effects" "Conflict controls" "Observations") fmt(a a a %9.0fc )) 
				;
				#delimit cr
	

***  B3: Ethnic connections and trade flows: Weighted exports between neighboring countries
	
	
use "$data\Trade_Data.dta", clear

eststo clear
foreach var of varlist Export  {
	qui {
	cap drop lnmean
	cap drop mean
	bysort dyad: egen mean = mean(`var')
	gen lnmean = log(mean)
	*
* two way clustered se
		reghdfe lnmean lnMS_SM    if border_n==1&year==2010  , cluster(dest_code country_code) a(dest_code country_code) keepsingletons
		matrix twoway = e(V)
		matrix twoway[1,1] = sqrt(twoway[1,1])
	* Correct "Dyad" cluster
	eststo: reghdfe lnmean lnMS_SM  if border_n==1&year==2010  , cluster(dyad_cluster) a(dest_code country_code) keepsingletons	
		estadd matrix TW = twoway
		
		estadd local pair = ""
		

* two way clustered se
		reghdfe lnmean lnMS_SM $pair  Linguistic_Similarity Genetic_Similarity if border_n==1&year==2010  , cluster(dest_code country_code) a(dest_code country_code) keepsingletons
		matrix twoway = e(V)
		matrix twoway[1,1] = sqrt(twoway[1,1])
	* Correct "Dyad" cluster
	eststo: reghdfe lnmean lnMS_SM  $pair Linguistic_Similarity Genetic_Similarity if border_n==1&year==2010  , cluster(dyad_cluster) a(dest_code country_code) keepsingletons	
		estadd matrix TW = twoway
		
		estadd local pair = "Yes"
		
		
* two way clustered se
		reghdfe lnmean lnMS_SM  $pair  if border_n==1&year==2010 [fw=pos_trade] , cluster(dest_code country_code) a(dest_code country_code) keepsingletons
		matrix twoway = e(V)
		matrix twoway[1,1] = sqrt(twoway[1,1])
	* Correct "Dyad" cluster
	eststo: reghdfe lnmean lnMS_SM  $pair  if border_n==1&year==2010 [fw=pos_trade] , cluster(dyad_cluster) a(dest_code country_code) keepsingletons	
		estadd matrix TW = twoway
		
		estadd local pair = "Yes"
		estadd local weight = "Yes"
		
		

	* two way clustered se	
		ppmlhdfe mean lnMS_SM $pair Linguistic_Similarity Genetic_Similarity  if border_n==1&year==2010 [fw=pos_trade] , cluster(dest_code country_code) a(dest_code country_code) keepsingletons
		matrix twoway = e(V)
		matrix twoway[1,1] = sqrt(twoway[1,1])
	eststo:	ppmlhdfe mean lnMS_SM $pair Linguistic_Similarity Genetic_Similarity   if border_n==1&year==2010 [fw=pos_trade] , cluster(dyad_cluster) a(dest_code country_code) keepsingletons
	* Correct "Dyad" Cluster
		estadd matrix TW = twoway
		estadd local pair = "Yes"
		estadd local weight = "Yes"
		
	
		


	}
	esttab est*, keep(lnMS_SM  ) cells(b(fmt(%9.3f) star  ) se(par) TW(par([ ])) ) starlevels( * 0.1 ** 0.05 *** 0.01 ) ///
		stats( pair timesyear conflict N, ///
		label("Country-pair controls" "Exporter and importer \(\times\) year fixed effects" "Conflict controls" ) ///
		fmt(a a a %9.0fc )) coeflabel(lnMS_SM "Ethnic connections" Linguistic_Similarity  "Linguistic distance" Genetic_Similarity "Genetic distance" rta "Regional trade agreements" lnConflict "log(\# Conflict)" lnCivillian "log(\# Civilian deaths)" lnDeath "log(\# Deaths)" ) varwidth(35)
			
	esttab using "$tables/B3_Mean.tex" ///
			, replace booktabs fragment ///
			keep(lnMS_SM  ) cells(b(fmt(%9.3f) star  label(" ")) se(par label(" ") ) TW(par([ ]) label(" ")))   ///
			star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
			coeflabel(lnMS_SM "Ethnic connections" Linguistic_Similarity "Linguistic distance" Genetic_Similarity "Genetic distance" rta "Regional trade agreements" lnConflict "log(\# Conflict)" lnCivillian "log(\# Civilian deaths)" lnDeath "log(\# Deaths)" ) ///
			nomtitles nonumbers nodepvars noobs nonote nogaps noline ///
			substitute(\_ _ / ) 		 			
}			

		// bring panels together
				#delimit ;
				esttab using "$tables/B3_Trade_Mean.tex", replace booktabs
					cells(none) nonote noobs nomtitles ///
					mgroups("OLS" "PPML"  , pattern(1 0 0  1  ) 
					prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
					prefoot(
					\panelinput{"$tables/B3_Mean.tex"} 
					\\
					\midrule )
					substitute(\_ _)	
				stats( pair weight N, ///
					label("Country-pair controls" "Weighted regression" "Observations") fmt(a a %9.0fc )) 
				;
				#delimit cr
				
	
	
***  B4 Ethnic connections and trade flows: Sectoral exports between neighboring countries

use "$data\Trade_Data.dta", clear
	eststo clear
foreach var of varlist Export Export_Manufacturing Export_Agriculture Export_Resources {
	qui {
	cap drop ln`var'
	gen ln`var'=log(`var'+1)

	*
	
		
* two way clustered se
		reghdfe ln`var' lnMS_SM  $pair Linguistic_Similarity Genetic_Similarity   if border_n==1 , cluster(dest_code country_code) a(dest_code##year country_code##year) keepsingletons
		matrix twoway = e(V)
		matrix twoway[1,1] = sqrt(twoway[1,1])
	* Correct "Dyad" cluster
	eststo: reghdfe ln`var' lnMS_SM  $pair Linguistic_Similarity Genetic_Similarity   if border_n==1 , cluster(dyad_cluster) a(dest_code##year country_code##year) keepsingletons	
		estadd matrix TW = twoway
		
		estadd local pair = "Yes"
		estadd local timesyear= "Yes"
		
		
		
	
		
		
	
		
}

	}
	esttab est*, keep(lnMS_SM  ) cells(b(fmt(%9.3f) star  ) se(par) TW(par([ ])) ) starlevels( * 0.1 ** 0.05 *** 0.01 ) ///
		stats( pair timesyear  N, ///
		label("Country-pair controls" "Exporter and importer \(\times\) year fixed effects" "Conflict controls" ) ///
		fmt(a a a %9.0fc )) coeflabel(lnEN "Ethnic connections" Linguistic_Similarity  "Linguistic distance" Genetic_Similarity "Genetic distance" ) varwidth(35)
			
	esttab using "$tables/B4_Sector.tex" ///
			, replace booktabs fragment ///
			keep(lnMS_SM   ) cells(b(fmt(%9.3f) star  label(" ")) se(par label(" ") ) TW(par([ ]) label(" ")))   ///
			star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
			coeflabel(lnMS_SM "Ethnic connections" Linguistic_Similarity "Linguistic distance" Genetic_Similarity "Genetic distance" rta "Regional trade agreements" lnConflict "log(\# Conflict)" lnCivillian "log(\# Civilian deaths)" lnDeath "log(\# Deaths)" ) ///
			nomtitles nonumbers nodepvars noobs nonote nogaps noline ///
			substitute(\_ _ / ) 		 			
			

		// bring panels together
				#delimit ;
				esttab using "$tables/B4_Trade_Sector.tex", replace booktabs
					cells(none) nonote noobs nomtitles ///
					mgroups("log(Export)" "log(Manufacturing)" "log(Agriculture)" "log(Resources)"  , pattern(1 1 1 1 ) 
					prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
					prefoot(
					\panelinput{"$tables/B4_Sector.tex"} 
					\\
					\midrule )
					substitute(\_ _)	
				stats( pair timesyear N, ///
					label("Country-pair controls" "Exporter and importer \(\times\) year fixed effects" "Conflict controls" "Observations") fmt(a a a %9.0fc )) 
				;
				#delimit cr

	
	
*** B5: Ethnic connections and trade flows Alternative population data

use "$data\Trade_Data.dta", clear


eststo clear
foreach var of varlist Export  {
	qui foreach dvar of varlist lnMS_SM lnPC_SM EN1960_M lnSM_Today  {
	cap drop ln`var'
	gen ln`var'=log(`var')
	*
		
* two way clustered se
		reghdfe ln`var' `dvar'  $pair Linguistic_Similarity Genetic_Similarity if border_n==1 , cluster(dest_code country_code) a(dest_code##year country_code##year) keepsingletons
		matrix twoway = e(V)
		matrix twoway[1,1] = sqrt(twoway[1,1])
	* Correct "Dyad" cluster
	eststo: reghdfe ln`var' `dvar'  $pair Linguistic_Similarity Genetic_Similarity  if border_n==1 , cluster(dyad_cluster) a(dest_code##year country_code##year) keepsingletons	
		estadd matrix TW = twoway
		
		estadd local pair = "Yes"
		estadd local timesyear= "Yes"
		estadd local conflict= "Yes"
		
		


	}
	esttab est*, keep(lnMS_SM lnPC_SM EN1960_M lnSM_Today ) cells(b(fmt(%9.3f) star  ) se(par) TW(par([ ])) ) starlevels( * 0.1 ** 0.05 *** 0.01 ) ///
		stats( pair timesyear conflict N, ///
		label("Country-pair controls" "Exporter and importer \(\times\) year fixed effects" "Conflict controls" ) ///
		fmt(a a a %9.0fc )) coeflabel(lnEN "Ethnic connections" Linguistic_Similarity  "Linguistic distance" Genetic_Similarity "Genetic distance" rta "Regional trade agreements" lnConflict "log(\# Conflict)" lnCivillian "log(\# Civilian deaths)" lnDeath "log(\# Deaths)" ) varwidth(35)
		
	esttab using "$tables/B5_`var'_alt.tex" ///
			, replace booktabs fragment ///
			keep(lnMS_SM lnPC_SM EN1960_M lnSM_Today ) cells(b(fmt(%9.3f) star  label(" ")) se(par label(" ") ) TW(par([ ]) label(" ")))   ///
			star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
			coeflabel(lnMS_SM "Ethnic connections" lnPC_SM "Ethnic connections, pre-colonial population" EN1960_M "Ethnic network according to model" lnSM_Today "Ethnic connections, Ethnologue data today") ///
			nomtitles nonumbers nodepvars noobs nonote nogaps noline ///
			substitute(\_ _ / ) 		 			
		
}
		// bring panels together
				#delimit ;
				esttab using "$tables/B5_Trade_alt.tex", replace booktabs
					cells(none) nonote noobs nomtitles ///
					mgroups("OLS" , pattern(1 0 0  ) 
					prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
					prefoot(
					\panelinput{"$tables/B5_Export_alt.tex"} 
					\\
					\midrule )
					substitute(\_ _)	
				stats( pair timesyear N, ///
					label("Country-pair controls" "Exporter and importer \(\times\) year fixed effects" "Conflict controls" "Observations") fmt(a a a %9.0fc )) 
				;
				#delimit cr

	
*** B6: IV Results: Trade exposure and the gains from trade: Using a PPML estimation in the first stage

use "$data/NTL_Trade_Data.dta", clear

* Dependent Variable
cap drop Trade_Expos*
gen Trade_Exposure = lnExport*popshare_tribe
gen Trade_Exposure_OLS = lnOLS_SM_Border*popshare_tribe
gen Trade_Exposure_PPML = lnPPML_SM_Border*popshare_tribe
gen Trade_Exposure_LOO = lnExport_loo*popshare_tribe
gen Trade_Exposure_LOO_NB = lnExport_loo_nonborder*popshare_tribe

* Political variable
tab status
cap drop EPR
gen EPR = 0 if status=="DISCRIMINATED"|status=="POWERLESS"|status=="IRRELEVANT"|status=="STATE COLLAPSE"
replace EPR = 1 if status=="JUNIOR PARTNER"|status=="SENIOR PARTNER"	// Junior partys
replace EPR = 2 if status=="MONOPOLY"|status=="DOMINANT"	// Dominating
tab EPR

cap drop InPower Trade_InPower
recode EPR (0 1 = 0) (2 = 1) , gen(InPower)

* Interaction
gen Trade_InPower = Trade_Exposure*InPower
gen Trade_OLS_InPower = Trade_Exposure_OLS*InPower
gen Trade_PPML_InPower = Trade_Exposure_PPML*InPower
gen Trade_LOO_InPower = Trade_Exposure_LOO*InPower
gen Trade_LOO_NB_InPower = Trade_Exposure_LOO_NB*InPower

* Cluster:
gen cXe = country_code*1000+tribe_code

*** OLS Instrument:

foreach var of varlist Lid lnNTL   {
qui {
	eststo clear
	eststo: ivreghdfe `var' Trade_Exposure , a(country_code##year country_code##tribe_code ) cl(cXe) 

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		
	
	eststo: reghdfe `var' Trade_Exposure Trade_InPower , a(country_code##year##InPower country_code##tribe_code ) cl(cXe) 

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		estadd local reduced ""
		
	foreach dvar of varlist lnOLS_SM_Border  lnPPML_SM_Border {
    
		cap drop Trade_IV_Power
		cap drop Trade_IV_Exposure
		gen Trade_IV_Exposure = `dvar'*popshare_tribe
		gen Trade_IV_Power = Trade_IV_Exposure*InPower

	eststo: ivreghdfe `var' (Trade_Exposure=Trade_IV_Exposure) , a(country_code##year country_code##tribe_code ) cl(cXe) 

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		
	
	eststo: reghdfe `var' Trade_IV_Exposure Trade_IV_Power , a(country_code##year##InPower country_code##tribe_code ) cl(cXe) 

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		estadd local reduced "Yes"
		
	}
}
esttab, drop(_cons  ) star(* 0.1 ** 0.05 *** 0.01)  stat(countryyear Ethniccountry reduced rkf N)

esttab  using "$tables/B6_IV_`var'_App.tex" ///
		, replace booktabs fragment ///
		keep(Trade_*) cells(b(fmt(%9.3f) star  label(" ")) se(par label(" ") ))   ///
		star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
		coeflabel(Trade_Exposure "Trade Exposure" Trade_InPower "Trade Exposure \(\times\) In Power" Trade_IV_Exposure "Predicted Trade Exposure" Trade_IV_Power  "Predicted Trade Exposure \(\times\) In Power") ///
		nomtitles nonumbers nodepvars noobs nonote nogaps noline ///
		substitute(\_ _ / ) 
	
		
}

// bring panels together
	#delimit ;
	esttab using "$tables/B6_IV_Panel_App.tex", replace booktabs
		cells(none) nonote noobs mtitles("OLS" "OLS" "IV" "RF" "IV" "RF") ///
		mgroups("OLS" "Cross-Border (OLS)" "Cross-Border (PPML)", pattern(1 0 1 0 1 0  ) 
		prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
		prefoot(  
		\multicolumn{@span}{l}{\emph{Panel A: Fraction of pixel lit }} \\ 
		\panelinput{"$tables/B6_IV_Lid_App.tex"} 
		\midrule \multicolumn{@span}{l}{\emph{Panel B: Average nighttime luminosity}} \\ 
		\panelinput{"$tables/B6_IV_lnNTL_App.tex"} 
		\midrule )
		substitute(\_ _)	
	stats( countryyear Ethniccountry reduced N rkf , ///
		label("Country \(\times\) year fixed effects" "Country \(\times\) ethnicity fixed effects" "Reduced form" "Observations" "First Stage F-Test") fmt(a a a %9.0fc %9.3f  )) 
	;
	#delimit cr	
	
	
	
*** B7:Trade exposure, wealth, and society: Using a PPML estimation in the first stage 


use "$data/Afrobarometer_Trade.dta", clear

* Dependent Variable
cap drop Trade_Expos*
gen Trade_Exposure = lnExport*popshare_tribe
gen Trade_Exposure_OLS = lnOLS_EN_Border*popshare_tribe
gen Trade_Exposure_PPML = lnPPML_EN_Border*popshare_tribe

* Political variable

cap drop EPR
gen EPR = 0 if status=="DISCRIMINATED"|status=="POWERLESS"|status=="IRRELEVANT"|status=="STATE COLLAPSE"
replace EPR = 1 if status=="JUNIOR PARTNER"|status=="SENIOR PARTNER"	// Junior partys
replace EPR = 2 if status=="MONOPOLY"|status=="DOMINANT"	// Dominating
tab EPR

cap drop InPower Trade_InPower
recode EPR (0 1 = 0) (2 = 1) , gen(InPower)

* Interaction
gen Trade_InPower = Trade_Exposure*InPower
gen Trade_OLS_InPower = Trade_Exposure_OLS*InPower
gen Trade_PPML_InPower = Trade_Exposure_PPML*InPower

*cluster
gen cXe = country_code*1000+tribe_code

*** OLS Instrument:


 foreach var of varlist z_Household z_Democracy z_Trust {
eststo clear
 qui {

			
	eststo: reghdfe `var' Trade_Exposure , a(country_code##year country_code##tribe_code Age Male Education Urban) cl(cXe) 

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"					
		estadd local ind 	"Yes"			
		
	eststo: reghdfe `var' Trade_Exposure Trade_InPower, a(country_code##year##InPower country_code##tribe_code Age Male Education Urban) cl(country_code#tribe_code) tol(1e-4)

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"					
		estadd local ind 	"Yes"		
		estadd local reduced ""
		
	foreach dvar of varlist lnOLS_SM_Border lnPPML_SM_Border {
    
		cap drop Trade_IV_Power
		cap drop Trade_IV_Exposure
		gen Trade_IV_Exposure = `dvar'*popshare_tribe
		gen Trade_IV_Power = Trade_IV_Exposure*InPower

	eststo: ivreghdfe `var' (Trade_Exposure=Trade_IV_Exposure) , a(country_code##year##InPower country_code##tribe_code Age Male Education Urban)  cl(cXe)  

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		
	
	eststo: reghdfe `var' Trade_IV_Exposure Trade_IV_Power , a(country_code##year##InPower country_code##tribe_code Age Male Education Urban)  cl(cXe)  

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		estadd local reduced "Yes"
		
	}
	
}

esttab, drop(_cons  ) star(* 0.1 ** 0.05 *** 0.01)  stat(countryyear Ethniccountry ind N rkf) 	

esttab  using "$tables/B7_IV_`var'_App.tex" ///
		, replace booktabs fragment ///
		keep(Trade_*) cells(b(fmt(%9.3f) star  label(" ")) se(par label(" ") ))   ///
		star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
		coeflabel(Trade_Exposure "Trade Exposure" Trade_InPower "Trade Exposure \(\times\) In Power" Trade_IV_Exposure "Predicted Trade Exposure" Trade_IV_Power  "Predicted Trade Exposure \(\times\) In Power") ///
		nomtitles nonumbers nodepvars noobs nonote nogaps noline ///
		substitute(\_ _ / ) 
		
}


// bring panels together
	#delimit ;
	esttab using "$tables/B7_AB_Panel_App.tex", replace booktabs
		cells(none) nonote noobs mtitles("OLS" "OLS" "IV" "RF" "IV" "RF") ///
		mgroups("OLS" "Cross-Border (OLS)" "Cross-Border (PPML)", pattern(1 0 1 0 1 0  ) 
		prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
		prefoot(  
		\multicolumn{@span}{l}{\emph{Panel A: Household wealth }} \\ 
		\panelinput{"$tables/B7_IV_z_Household_App.tex"} 
		\midrule \multicolumn{@span}{l}{\emph{Panel B: Satisfaction with Democracy}} \\ 
		\panelinput{"$tables/B7_IV_z_Democracy_App.tex"} 
		\midrule \multicolumn{@span}{l}{\emph{Panel C: Trust in Institutions}} \\ 
		\panelinput{"$tables/B7_IV_z_Trust_App.tex"} 
		\midrule )
		substitute(\_ _)	
	stats( countryyear Ethniccountry ind reduced N rkf , ///
		label("Country \(\times\) year fixed effects" "Country \(\times\) ethnicity fixed effects" "Individual controls" "Reduced form" "Observations" "First Stage F-Test") fmt(a a a a %9.0fc %9.3f  )) 
	;
	#delimit cr	
	
	
	
*** B8: Trade exposure, wealth, and society Bootstrapped standard errors

local bs = 100	
use "$data/NTL_Trade_Data.dta", clear

* Dependent Variable
cap drop Trade_Expos*
gen Trade_Exposure = lnExport*popshare_tribe
gen Trade_Exposure_OLS = lnOLS_SM_Border*popshare_tribe
gen Trade_Exposure_PPML = lnPPML_SM_Border*popshare_tribe
gen Trade_Exposure_LOO = lnExport_loo*popshare_tribe
gen Trade_Exposure_LOO_NB = lnExport_loo_nonborder*popshare_tribe

* Political variable
tab status
cap drop EPR
gen EPR = 0 if status=="DISCRIMINATED"|status=="POWERLESS"|status=="IRRELEVANT"|status=="STATE COLLAPSE"
replace EPR = 1 if status=="JUNIOR PARTNER"|status=="SENIOR PARTNER"	// Junior partys
replace EPR = 2 if status=="MONOPOLY"|status=="DOMINANT"	// Dominating
tab EPR

cap drop InPower Trade_InPower
recode EPR (0 1 = 0) (2 = 1) , gen(InPower)

* Interaction
gen Trade_InPower = Trade_Exposure*InPower
gen Trade_OLS_InPower = Trade_Exposure_OLS*InPower
gen Trade_PPML_InPower = Trade_Exposure_PPML*InPower
gen Trade_LOO_InPower = Trade_Exposure_LOO*InPower
gen Trade_LOO_NB_InPower = Trade_Exposure_LOO_NB*InPower

* Cluster:
gen cXe = country_code*1000+tribe_code

*** OLS Instrument:
	eststo clear
qui foreach var of varlist Lid lnNTL   {
 			
	foreach dvar of varlist lnOLS_SM_Border  lnExport_loo {
    
		
		cap drop Trade_IV_Exposure
		gen Trade_IV_Exposure = `dvar'*popshare_tribe
		

	eststo: bootstrap _b _se, reps(`bs') : ivreghdfe `var' (Trade_Exposure=Trade_IV_Exposure) , a(country_code##year country_code##tribe_code ) cl(cXe) 

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		
	}

esttab, star(* 0.1 ** 0.05 *** 0.01)  stat(countryyear Ethniccountry reduced rkf N)

		
}

	

use "$data/Afrobarometer_Trade.dta", clear

* Dependent Variable
cap drop Trade_Expos*
gen Trade_Exposure = lnExport*popshare_tribe
gen Trade_Exposure_OLS = lnOLS_EN_Border*popshare_tribe
gen Trade_Exposure_PPML = lnPPML_EN_Border*popshare_tribe

* Political variable

cap drop EPR
gen EPR = 0 if status=="DISCRIMINATED"|status=="POWERLESS"|status=="IRRELEVANT"|status=="STATE COLLAPSE"
replace EPR = 1 if status=="JUNIOR PARTNER"|status=="SENIOR PARTNER"	// Junior partys
replace EPR = 2 if status=="MONOPOLY"|status=="DOMINANT"	// Dominating
tab EPR

cap drop InPower Trade_InPower
recode EPR (0 1 = 0) (2 = 1) , gen(InPower)

* Interaction
gen Trade_InPower = Trade_Exposure*InPower
gen Trade_OLS_InPower = Trade_Exposure_OLS*InPower
gen Trade_PPML_InPower = Trade_Exposure_PPML*InPower

*cluster
gen cXe = country_code*1000+tribe_code

*** OLS Instrument:


 foreach var of varlist z_Household z_Democracy z_Trust {

 qui {

	foreach dvar of varlist lnOLS_SM_Border lnExport_loo {
    
		cap drop Trade_IV_Exposure
		gen Trade_IV_Exposure = `dvar'*popshare_tribe


	eststo: bootstrap _b _se, reps(`bs') :  ivreghdfe `var' (Trade_Exposure=Trade_IV_Exposure) , a(country_code##year##InPower country_code##tribe_code Age Male Education Urban)  cl(cXe)  

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		estadd local ind "Yes"
		
	}
	
}

esttab,  star(* 0.1 ** 0.05 *** 0.01)  stat(countryyear Ethniccountry ind N rkf) 	
}


esttab  using "$tables/B8_IV_BS.tex" ///
		, replace booktabs fragment ///
		keep(Trade_*) cells(b(fmt(%9.3f) star  label(" ")) se(par label(" ") ))   ///
		star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
		coeflabel(Trade_Exposure "Trade Exposure" Trade_InPower "Trade Exposure \(\times\) In Power" Trade_IV_Exposure "Predicted Trade Exposure" Trade_IV_Power  "Predicted Trade Exposure \(\times\) In Power") ///
		nomtitles nonumbers nodepvars noobs nonote nogaps noline ///
		substitute(\_ _ / ) 
		
// bring panels together
	#delimit ;
esttab using "$tables/B8_IV_Panel_BS.tex", replace booktabs
		cells(none) nonote noobs mtitles("CB" "LOO" "CB" "LOO" "CB" "LOO" "CB" "LOO" "CB" "LOO") ///
		mgroups("Fraction Lit" "Average luminosity" "Household wealth" "Satis. w. Democracy" "Trust in Inst.", pattern(1 0 1 0 1 0 1 0 1 0 ) 
		prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
		prefoot(  
		\panelinput{"$tables/B8_IV_BS.tex"} 
		\\
		\midrule )
		substitute(\_ _)	
	stats( countryyear Ethniccountry ind N  , ///
		label("Country \(\times\) year fixed effects" "Country \(\times\) ethnicity fixed effects" "Individual controls" "Reduced form" "Observations" "First Stage F-Test") fmt(a a a a %9.0fc %9.3f  )) 
	;
	#delimit cr	


*** Figure B1 Export share


use "$data\Trade_Data.dta", clear
keep if border_n==1

bysort country_code year: egen TES = sum(d_ethnicshare_Murdock_SM)
gen EthnicShare = d_ethnicshare_Murdock_SM/TES

bysort country_code year: egen TEXP = sum(Export)
gen ExportShare = Export/TEXP
		
	 			
binscatter ExportShare EthnicShare	if border_n==1 , ///
	xtitle(Share of Ethnic Network) ytitle(Share of Cross-Border Exports) 
graph save "$figures/g1.gph", replace 			
			
use "$data\Trade_Data.dta", clear

bysort country_code year: egen TES = sum(d_ethnicshare_Murdock_SM)
gen EthnicShare = d_ethnicshare_Murdock_SM/TES

bysort country_code year: egen TEXP = sum(Export)
gen ExportShare = Export/TEXP

	 			
binscatter ExportShare EthnicShare	if border_n==1 , ///
	xtitle(Share of Ethnic Network) ytitle(Share of All Exports)  
	graph save "$figures/g2.gph", replace

graph combine "$figures/g1.gph" "$figures/g2.gph" , ycommon
graph export "$figures/Exportshare.png", replace width(1000)

	
********************************************************************************
*** Appendix C : Afrobarometer
********************************************************************************	

********************************************************************************
* Multiple hypothesis testing
********************************************************************************

use "$data/Afrobarometer_Trade.dta", clear

local household ///
	Country_Condition Household_Condition_Compared Household_Condition Household_Past_Condition ///
	With_Food With_Water With_Cash With_Fuel  
	
local trust ///
	 Trust_President Trust_Electoral_Commission Trust_Ruling_Party Trust_Traditional_Leaders
	 
local democracy ///
	Democracy_Status Democracy_Satisfied  Freedom_Speech 

* Dependent Variable
cap drop Trade_Expos*
gen Trade_Exposure = lnExport*popshare_tribe
	
local list `household'
{
local m : list sizeof local(list)
di `m'

cap drop yhat_* 
cap drop xhat
eststo clear 
mat TABLE = J(`m',4,.)
mat PVALINFO = J(`m',1,.)
mat SEINFO = J(`m',1,.)
local n = 0
qui foreach var of varlist `list' {
	local n = `n'+1
	cap drop yhat 
	cap drop xhat
	qui reghdfe `var' Trade_Exposure , a(country_code##year country_code##tribe_code Age Male Education Urban) cl(country_code#tribe_code) tol(1e-4)
	
	mat PVALINFO[`n',1]=(2*(1-normal(abs(_b[Trade_Exposure]/_se[Trade_Exposure]))))
	mat SEINFO[`n',1] = _se[Trade_Exposure]
	
	mat TABLE[`n',1] = _b[Trade_Exposure]
	mat TABLE[`n',2] = _se[Trade_Exposure]
	mat TABLE[`n',3] = PVALINFO[`n',1]
	
	di _se[Trade_Exposure]
	}


mat list PVALINFO

preserve
clear
svmat PVALINFO

gen float PVALINFO  = PVALINFO1
drop if PVALINFO==.
* Stuff from anderson 2008 
qui {

quietly sum PVALINFO
local totalPVALINFOs = r(N)

* Sort the p-values in ascending order and generate a variable that codes each p-value's rank

quietly gen int original_sorting_order = _n
quietly sort PVALINFO
quietly gen int rank = _n if PVALINFO~=.

* Set the initial counter to 1 

local qval = 1

* Generate the variable that will contain the BKY (2006) sharpened q-values

gen bky06_qval = 1 if PVALINFO~=.

* Set up a loop that begins by checking which hypotheses are rejected at q = 1.000, then checks which hypotheses are rejected at q = 0.999, then checks which hypotheses are rejected at q = 0.998, etc.  The loop ends by checking which hypotheses are rejected at q = 0.001.


while `qval' > 0 {
	* First Stage
	* Generate the adjusted first stage q level we are testing: q' = q/1+q
	local qval_adj = `qval'/(1+`qval')
	* Generate value q'*r/M
	gen fdr_temp1 = `qval_adj'*rank/`totalPVALINFOs'
	* Generate binary variable checking condition p(r) <= q'*r/M
	gen reject_temp1 = (fdr_temp1>=PVALINFO) if PVALINFO~=.
	* Generate variable containing p-value ranks for all p-values that meet above condition
	gen reject_rank1 = reject_temp1*rank
	* Record the rank of the largest p-value that meets above condition
	egen total_rejected1 = max(reject_rank1)

	* Second Stage
	* Generate the second stage q level that accounts for hypotheses rejected in first stage: q_2st = q'*(M/m0)
	local qval_2st = `qval_adj'*(`totalPVALINFOs'/(`totalPVALINFOs'-total_rejected1[1]))
	* Generate value q_2st*r/M
	gen fdr_temp2 = `qval_2st'*rank/`totalPVALINFOs'
	* Generate binary variable checking condition p(r) <= q_2st*r/M
	gen reject_temp2 = (fdr_temp2>=PVALINFO) if PVALINFO~=.
	* Generate variable containing p-value ranks for all p-values that meet above condition
	gen reject_rank2 = reject_temp2*rank
	* Record the rank of the largest p-value that meets above condition
	egen total_rejected2 = max(reject_rank2)

	* A p-value has been rejected at level q if its rank is less than or equal to the rank of the max p-value that meets the above condition
	replace bky06_qval = `qval' if rank <= total_rejected2 & rank~=.
	* Reduce q by 0.001 and repeat loop
	drop fdr_temp* reject_temp* reject_rank* total_rejected*
	local qval = `qval' - .001
}
	

quietly sort original_sorting_order


display "Code has completed."
display "Benjamini Krieger Yekutieli (2006) sharpened q-vals are in variable 'bky06_qval'"
display	"Sorting order is the same as the original vector of p-values"


* Note: Sharpened FDR q-vals can be LESS than unadjusted p-vals when many hypotheses are rejected, because if you have many true rejections, then you can tolerate several false rejections too (this effectively just happens for p-vals that are so large that you are not going to reject them regardless).
}

mkmat bky06_qval,mat(PVALINFO_CORR)

restore
*mat rownames PVALINFO = $info
*mat rownames PVALINFO_CORR = $info
mat list PVALINFO 
mat list PVALINFO_CORR


forvalues var = 1(1) `m '{ 
	
	mat TABLE[`var',4] = PVALINFO_CORR[`var',1]
	
}
mat list TABLE
}
outtable using "$tables\MHT.tex" , mat(TABLE) replace nobox caption(Wealth)

	
	esttab mat(TABLE, fmt(3)) using "$tables\MHT_Household.tex" ///
			, replace booktabs fragment  cells(fmt(%9.3f)) ///
			nomtitles nonumbers noobs nonote nogaps noline  substitute(\_ _  c1 "" c2 "" c3 "" c4 "") ///
			coeflabels(	r1 "Country Condition" r2 "Household Condition, Compared" r3 "Household Condition" /// 
						r4 "Household Condition, Past" r5 "Days with Food" r6 "Days with Water" /// 
						r7 "Days with Cash" r8 "Days with Fuel"  )					

local list `trust'
{
local m : list sizeof local(list)
di `m'

cap drop yhat_* 
cap drop xhat
eststo clear 
mat TABLE = J(`m',4,.)
mat PVALINFO = J(`m',1,.)
mat SEINFO = J(`m',1,.)
local n = 0
qui foreach var of varlist `list' {
	local n = `n'+1
	cap drop yhat 
	cap drop xhat
	qui reghdfe `var' Trade_Exposure , a(country_code##year country_code##tribe_code Age Male Education Urban) cl(country_code#tribe_code) tol(1e-4)
	
	mat PVALINFO[`n',1]=(2*(1-normal(abs(_b[Trade_Exposure]/_se[Trade_Exposure]))))
	mat SEINFO[`n',1] = _se[Trade_Exposure]
	
	mat TABLE[`n',1] = _b[Trade_Exposure]
	mat TABLE[`n',2] = _se[Trade_Exposure]
	mat TABLE[`n',3] = PVALINFO[`n',1]
	
	di _se[Trade_Exposure]
	}


mat list PVALINFO

preserve
clear
svmat PVALINFO

gen float PVALINFO  = PVALINFO1
drop if PVALINFO==.
* Stuff from anderson 2008 
qui {

quietly sum PVALINFO
local totalPVALINFOs = r(N)

* Sort the p-values in ascending order and generate a variable that codes each p-value's rank

quietly gen int original_sorting_order = _n
quietly sort PVALINFO
quietly gen int rank = _n if PVALINFO~=.

* Set the initial counter to 1 

local qval = 1

* Generate the variable that will contain the BKY (2006) sharpened q-values

gen bky06_qval = 1 if PVALINFO~=.

* Set up a loop that begins by checking which hypotheses are rejected at q = 1.000, then checks which hypotheses are rejected at q = 0.999, then checks which hypotheses are rejected at q = 0.998, etc.  The loop ends by checking which hypotheses are rejected at q = 0.001.


while `qval' > 0 {
	* First Stage
	* Generate the adjusted first stage q level we are testing: q' = q/1+q
	local qval_adj = `qval'/(1+`qval')
	* Generate value q'*r/M
	gen fdr_temp1 = `qval_adj'*rank/`totalPVALINFOs'
	* Generate binary variable checking condition p(r) <= q'*r/M
	gen reject_temp1 = (fdr_temp1>=PVALINFO) if PVALINFO~=.
	* Generate variable containing p-value ranks for all p-values that meet above condition
	gen reject_rank1 = reject_temp1*rank
	* Record the rank of the largest p-value that meets above condition
	egen total_rejected1 = max(reject_rank1)

	* Second Stage
	* Generate the second stage q level that accounts for hypotheses rejected in first stage: q_2st = q'*(M/m0)
	local qval_2st = `qval_adj'*(`totalPVALINFOs'/(`totalPVALINFOs'-total_rejected1[1]))
	* Generate value q_2st*r/M
	gen fdr_temp2 = `qval_2st'*rank/`totalPVALINFOs'
	* Generate binary variable checking condition p(r) <= q_2st*r/M
	gen reject_temp2 = (fdr_temp2>=PVALINFO) if PVALINFO~=.
	* Generate variable containing p-value ranks for all p-values that meet above condition
	gen reject_rank2 = reject_temp2*rank
	* Record the rank of the largest p-value that meets above condition
	egen total_rejected2 = max(reject_rank2)

	* A p-value has been rejected at level q if its rank is less than or equal to the rank of the max p-value that meets the above condition
	replace bky06_qval = `qval' if rank <= total_rejected2 & rank~=.
	* Reduce q by 0.001 and repeat loop
	drop fdr_temp* reject_temp* reject_rank* total_rejected*
	local qval = `qval' - .001
}
	

quietly sort original_sorting_order


display "Code has completed."
display "Benjamini Krieger Yekutieli (2006) sharpened q-vals are in variable 'bky06_qval'"
display	"Sorting order is the same as the original vector of p-values"


* Note: Sharpened FDR q-vals can be LESS than unadjusted p-vals when many hypotheses are rejected, because if you have many true rejections, then you can tolerate several false rejections too (this effectively just happens for p-vals that are so large that you are not going to reject them regardless).
}

mkmat bky06_qval,mat(PVALINFO_CORR)

restore
*mat rownames PVALINFO = $info
*mat rownames PVALINFO_CORR = $info
mat list PVALINFO 
mat list PVALINFO_CORR


forvalues var = 1(1) `m '{ 
	
	mat TABLE[`var',4] = PVALINFO_CORR[`var',1]
	
}
mat list TABLE
}
outtable using "$tables\MHT.tex" , mat(TABLE) append nobox caption(Trust)
	
	esttab mat(TABLE, fmt(3)) using "$tables\MHT_Trust.tex" ///
			, replace booktabs fragment  cells(fmt(%9.3f)) ///
			nomtitles nonumbers noobs nonote nogaps noline  substitute(\_ _  c1 "" c2 "" c3 "" c4 "") ///
			coeflabels(	r1 "Trust in President" r2 "Trust in Electoral Commission" r3 "Trust in Ruling Party" r4 "Trust in Traditional Leaders"  )	
	
local list `democracy'
{
local m : list sizeof local(list)
di `m'

cap drop yhat_* 
cap drop xhat
eststo clear 
mat TABLE = J(`m',4,.)
mat PVALINFO = J(`m',1,.)
mat SEINFO = J(`m',1,.)
local n = 0
qui foreach var of varlist `list' {
	local n = `n'+1
	cap drop yhat 
	cap drop xhat
	qui reghdfe `var' Trade_Exposure , a(country_code##year country_code##tribe_code Age Male Education Urban) cl(country_code#tribe_code) tol(1e-4)
	
	mat PVALINFO[`n',1]=(2*(1-normal(abs(_b[Trade_Exposure]/_se[Trade_Exposure]))))
	mat SEINFO[`n',1] = _se[Trade_Exposure]
	
	mat TABLE[`n',1] = _b[Trade_Exposure]
	mat TABLE[`n',2] = _se[Trade_Exposure]
	mat TABLE[`n',3] = PVALINFO[`n',1]
	
	di _se[Trade_Exposure]
	}


mat list PVALINFO

preserve
clear
svmat PVALINFO

gen float PVALINFO  = PVALINFO1
drop if PVALINFO==.
* Stuff from anderson 2008 
qui {

quietly sum PVALINFO
local totalPVALINFOs = r(N)

* Sort the p-values in ascending order and generate a variable that codes each p-value's rank

quietly gen int original_sorting_order = _n
quietly sort PVALINFO
quietly gen int rank = _n if PVALINFO~=.

* Set the initial counter to 1 

local qval = 1

* Generate the variable that will contain the BKY (2006) sharpened q-values

gen bky06_qval = 1 if PVALINFO~=.

* Set up a loop that begins by checking which hypotheses are rejected at q = 1.000, then checks which hypotheses are rejected at q = 0.999, then checks which hypotheses are rejected at q = 0.998, etc.  The loop ends by checking which hypotheses are rejected at q = 0.001.


while `qval' > 0 {
	* First Stage
	* Generate the adjusted first stage q level we are testing: q' = q/1+q
	local qval_adj = `qval'/(1+`qval')
	* Generate value q'*r/M
	gen fdr_temp1 = `qval_adj'*rank/`totalPVALINFOs'
	* Generate binary variable checking condition p(r) <= q'*r/M
	gen reject_temp1 = (fdr_temp1>=PVALINFO) if PVALINFO~=.
	* Generate variable containing p-value ranks for all p-values that meet above condition
	gen reject_rank1 = reject_temp1*rank
	* Record the rank of the largest p-value that meets above condition
	egen total_rejected1 = max(reject_rank1)

	* Second Stage
	* Generate the second stage q level that accounts for hypotheses rejected in first stage: q_2st = q'*(M/m0)
	local qval_2st = `qval_adj'*(`totalPVALINFOs'/(`totalPVALINFOs'-total_rejected1[1]))
	* Generate value q_2st*r/M
	gen fdr_temp2 = `qval_2st'*rank/`totalPVALINFOs'
	* Generate binary variable checking condition p(r) <= q_2st*r/M
	gen reject_temp2 = (fdr_temp2>=PVALINFO) if PVALINFO~=.
	* Generate variable containing p-value ranks for all p-values that meet above condition
	gen reject_rank2 = reject_temp2*rank
	* Record the rank of the largest p-value that meets above condition
	egen total_rejected2 = max(reject_rank2)

	* A p-value has been rejected at level q if its rank is less than or equal to the rank of the max p-value that meets the above condition
	replace bky06_qval = `qval' if rank <= total_rejected2 & rank~=.
	* Reduce q by 0.001 and repeat loop
	drop fdr_temp* reject_temp* reject_rank* total_rejected*
	local qval = `qval' - .001
}
	

quietly sort original_sorting_order


display "Code has completed."
display "Benjamini Krieger Yekutieli (2006) sharpened q-vals are in variable 'bky06_qval'"
display	"Sorting order is the same as the original vector of p-values"


* Note: Sharpened FDR q-vals can be LESS than unadjusted p-vals when many hypotheses are rejected, because if you have many true rejections, then you can tolerate several false rejections too (this effectively just happens for p-vals that are so large that you are not going to reject them regardless).
}

mkmat bky06_qval,mat(PVALINFO_CORR)

restore
*mat rownames PVALINFO = $info
*mat rownames PVALINFO_CORR = $info
mat list PVALINFO 
mat list PVALINFO_CORR


forvalues var = 1(1) `m '{ 
	
	mat TABLE[`var',4] = PVALINFO_CORR[`var',1]
	
}
mat list TABLE
}
outtable using "$tables\MHT.tex" , mat(TABLE) append nobox caption(Democracy)

mat list TABLE	, format(%9.3f)					
mat colnames TABLE =" "

	esttab mat(TABLE, fmt(3)) using "$tables\MHT_Democracy.tex" ///
			, replace booktabs fragment  cells(fmt(%9.3f)) ///
			nomtitles nonumbers noobs nonote nogaps noline  substitute(\_ _  c1 "" c2 "" c3 "" c4 "") ///
			coeflabels(	r1 "Status of Democracy" r2 "Satisfied with Democracy" r3 "Freedom of Speech" )




********************************************************************************
*** Appendix D : Replicating using DHS
********************************************************************************

* D1 Trade exposure and wealth gains: IV results in the DHS

use "$data/DHS_EPR.dta", clear

cap drop Trade_Expos*
gen Trade_Exposure = lnExport*popshare_tribe
gen Trade_Exposure_OLS = lnOLS_SM_Border*popshare_tribe
gen Trade_Exposure_PPML = lnPPML_SM_Border*popshare_tribe

gen Trade_InPower = Trade_Exposure*InPower

gen Urban = (URBAN_RURA=="U")
gen Age = agemn
gen Education = yrschlmn if yrschlmn<=14

gen Sleep= sleeprooms if sleeprooms<30
gen lnSR = log(Sleep+1)
gen Elec = electrchh if electrchh!=8


gen Work = currworkmn if currworkmn<3



cap program drop zscore
program define zscore 
	syntax, varlist(str) name(str) 
	
 	
	cap drop std_*
	local n = 0
	foreach var of varlist `varlist' {
		
		di "`var'"
		
		sum `var'
		if `r(N)' >0 {
			local n = `n'+1
			cap drop std_`n'
			* step 1: create variables
			* 0 is important as other wise(par) missing sample causes problems...
			gen std_`n' = 0 		
			replace std_`n' = `var'-`r(mean)' if `var'!=.
			sum `var' if Connected_Ethnic==0	// standardize using sd of control (step 2, p. 1485, Anderson 2008)
			replace std_`n' = std_`n'/`r(sd)'
			
		}	
	}
	corr std_*, cov
	mat C = inv(r(C))
	mat I = J(`n',1,1)
	mat WW = inv(I'*C*I)*(I'*C) // Formula to generate weights (step 4, p. 1485, Anderson 2008)
	mat list WW
	cap drop WW*
	svmat WW
	cap drop W_Test
	gen W_Test = 0 if WW1!=.
	forvalues n1 = 1(1)`n' {
		replace std_`n1' = std_`n1'* WW[1,`n1']
		replace W_Test = W_Test+WW`n1'
	}
	su W_Test

	cap drop `name'
	egen `name'= rowtotal(std_*)

end


cap drop z_DHS
qui zscore, varlist(Work Elec lnSR ) name(z_DHS)



foreach var of varlist z_DHS {
eststo clear
 qui {

			
	eststo: reghdfe `var' Trade_Exposure , a(country_code##year country_code##tribe_code Age  Education Urban) cl(cXe) 

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"					
		estadd local ind 	"Yes"			
		
	eststo: reghdfe `var' Trade_Exposure Trade_InPower, a(country_code##year##InPower country_code##tribe_code Age  Education Urban) cl(country_code#tribe_code) tol(1e-4)

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"					
		estadd local ind 	"Yes"		
		estadd local reduced ""
		
	foreach dvar of varlist lnOLS_SM_Border lnExport_loo {
    
		cap drop Trade_IV_Power
		cap drop Trade_IV_Exposure
		gen Trade_IV_Exposure = `dvar'*popshare_tribe
		gen Trade_IV_Power = Trade_IV_Exposure*InPower

	eststo: ivreghdfe `var' (Trade_Exposure=Trade_IV_Exposure) , a(country_code##year##InPower country_code##tribe_code Age  Education Urban)  cl(cXe)  

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		estadd local ind 	"Yes"
		
	
	eststo: reghdfe `var' Trade_IV_Exposure Trade_IV_Power , a(country_code##year##InPower country_code##tribe_code Age  Education Urban)  cl(cXe)  

		estadd local countryyear 	"Yes"
		estadd local Ethniccountry 	"Yes"	
		estadd local ind 	"Yes"
		estadd local reduced "Yes"
		
	}
	
}
}
esttab, drop(_cons  ) star(* 0.1 ** 0.05 *** 0.01)  stat(countryyear Ethniccountry ind N rkf) 	

esttab  using "$tables/D1_IV_z_DHS.tex" ///
		, replace booktabs fragment ///
		keep(Trade_*) cells(b(fmt(%9.3f) star  label(" ")) se(par label(" ") ))   ///
		star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
		coeflabel(Trade_Exposure "Trade Exposure" Trade_InPower "Trade Exposure \(\times\) In Power" Trade_IV_Exposure "Predicted Trade Exposure" Trade_IV_Power  "Predicted Trade Exposure \(\times\) In Power") ///
		nomtitles nonumbers nodepvars noobs nonote nogaps noline ///
		substitute(\_ _ / ) 
		
// bring panels together
	#delimit ;
	esttab using "$tables/D1_IV_Panel_z_DHS.tex", replace booktabs
		cells(none) nonote noobs mtitles("OLS" "OLS" "IV" "RF" "IV" "RF") ///
		mgroups("OLS" "Cross-Border" "Leave-One-Out", pattern(1 0 1 0 1 0  ) 
		prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
		prefoot(  
		\panelinput{"$tables/D1_IV_z_DHS.tex"} 
		\\
		\midrule )
		substitute(\_ _)	
	stats( countryyear Ethniccountry ind reduced N rkf , ///
		label("Country \(\times\) year fixed effects" "Country \(\times\) ethnicity fixed effects" "Individual controls" "Reduced form" "Observations" "First Stage F-Test") fmt(a a a a %9.0fc %9.3f  )) 
	;
	#delimit cr	


	
	
	
********************************************************************************
*** Appendix E: Theoretical Model, allowing for inter-ethnic trade
********************************************************************************	
use "$data/Trade_All.dta",clear	

foreach var of varlist Export Export_z{
	qui {

	eststo clear
		
		
	* two way clustered se
		reghdfe ln`var' EN1960  $pair_all Linguistic_Similarity Genetic_Similarity , cluster(dest_code country_code) a(dest_code##year country_code##year) keepsingletons
		matrix twoway = e(V)
		matrix twoway[1,1] = sqrt(twoway[1,1])
	* Correct "Dyad" cluster
	eststo: reghdfe ln`var' EN1960  $pair_all Linguistic_Similarity Genetic_Similarity , cluster(dyad_cluster) a(dest_code##year country_code##year) keepsingletons	
		estadd matrix TW = twoway
		
		estadd local pair = "Yes"
		estadd local timesyear= "Yes"
		
		
		
	
	* two way clustered se	
		ppmlhdfe `var' EN1960 $pair_all Linguistic_Similarity Genetic_Similarity , cluster(dest_code country_code) a(dest_code##year country_code##year) keepsingletons
		matrix twoway = e(V)
		matrix twoway[1,1] = sqrt(twoway[1,1])
	eststo:	ppmlhdfe `var' EN1960 $pair_all  Linguistic_Similarity Genetic_Similarity, cluster(dyad_cluster) a(dest_code##year country_code##year) keepsingletons
	* Correct "Dyad" Cluster
		estadd matrix TW = twoway
		estadd local pair = "Yes"
		estadd local timesyear= "Yes"
		
	

	* two way clustered se
		reghdfe ln`var' EN1960_2  $pair_all Linguistic_Similarity Genetic_Similarity , cluster(dest_code country_code) a(dest_code##year country_code##year) keepsingletons
		matrix twoway = e(V)
		matrix twoway[1,1] = sqrt(twoway[1,1])
	* Correct "Dyad" cluster
	eststo: reghdfe ln`var' EN1960_2  $pair_all Linguistic_Similarity Genetic_Similarity , cluster(dyad_cluster) a(dest_code##year country_code##year) keepsingletons	
		estadd matrix TW = twoway
		
		estadd local pair = "Yes"
		estadd local timesyear= "Yes"
		
	
	
	* two way clustered se	
		ppmlhdfe `var' EN1960_2 $pair_all Linguistic_Similarity Genetic_Similarity , cluster(dest_code country_code) a(dest_code##year country_code##year) keepsingletons
		matrix twoway = e(V)
		matrix twoway[1,1] = sqrt(twoway[1,1])
	eststo:	ppmlhdfe `var' EN1960_2 $pair_all  Linguistic_Similarity Genetic_Similarity, cluster(dyad_cluster) a(dest_code##year country_code##year) keepsingletons
	* Correct "Dyad" Cluster
		estadd matrix TW = twoway
		estadd local pair = "Yes"
		estadd local timesyear= "Yes"
		

	* two way clustered se
		reghdfe ln`var' EN1960_2dist  $pair_all Linguistic_Similarity Genetic_Similarity , cluster(dest_code country_code) a(dest_code##year country_code##year) keepsingletons
		matrix twoway = e(V)
		matrix twoway[1,1] = sqrt(twoway[1,1])
	* Correct "Dyad" cluster
	eststo: reghdfe ln`var' EN1960_2dist  $pair_all Linguistic_Similarity Genetic_Similarity , cluster(dyad_cluster) a(dest_code##year country_code##year) keepsingletons	
		estadd matrix TW = twoway
		
		estadd local pair = "Yes"
		estadd local timesyear= "Yes"
		
	
	
	* two way clustered se	
		ppmlhdfe `var' EN1960_2dist $pair_all Linguistic_Similarity Genetic_Similarity , cluster(dest_code country_code) a(dest_code##year country_code##year) keepsingletons
		matrix twoway = e(V)
		matrix twoway[1,1] = sqrt(twoway[1,1])
	eststo:	ppmlhdfe `var' EN1960_2dist $pair_all  Linguistic_Similarity Genetic_Similarity, cluster(dyad_cluster) a(dest_code##year country_code##year) keepsingletons
	* Correct "Dyad" Cluster
		estadd matrix TW = twoway
		estadd local pair = "Yes"
		estadd local timesyear= "Yes"		
		
	
		
	}
	esttab est*, keep(EN1960* ) cells(b(fmt(%9.3f) star  ) se(par) TW(par([ ])) ) starlevels( * 0.1 ** 0.05 *** 0.01 ) ///
		stats( pair timesyear N , ///
		label("Country-pair controls" "Exporter and importer \(\times\) year fixed effects"  ) ///
		fmt(a a %9.0fc %9.3fc )) coeflabel(lnMS_SM "Ethnic connections" lnMurdock_Dist "log Distance weighted match probability") varwidth(35)
			
		esttab using "$tables/E1_InterEthnic_`var'.tex" ///
			, replace booktabs fragment ///
			keep(EN1960 EN1960_2 EN1960_2dist ) cells(b(fmt(%9.3f) star  label(" ")) se(par label(" ") ) TW(par([ ]) label(" ")))   ///
			star(* 0.1 ** 0.05 *** 0.01) b(%9.3f) se ///
			coeflabel(	EN1960 "log(Size of Network)" EN1960_2 "log(Size of Network, exponent =0.2)" ///
						EN1960_2dist "log(Size of Network, exponent =0.2, with inter-ethnic networks)") ///
			nomtitles nonumbers nodepvars noobs nonote nogaps noline ///
			substitute(\_ _ / ) 
}			

exit 
	 		

// bring panels together
		#delimit ;
		esttab using "$tables/E1_InterEthnic_Trade_all.tex", replace booktabs
			cells(none) nonote noobs mtitles(OLS PPML OLS PPML OLS PPML) ///
			prefoot(
			\multicolumn{@span}{l}{\emph{Panel A: Exports between all countries}} \\ 
			\panelinput{"$tables/E1_InterEthnic_Export.tex"} \\
			\midrule 
			\multicolumn{@span}{l}{\emph{Panel B: Exports between all countries, missing trade set to zero}} \\ 
			\panelinput{"$tables/E1_InterEthnic_Export_z.tex"} \\
			\midrule )
			substitute(\_ _)	
		stats( pair timesyear N, ///
			label("Country-pair controls" "Exporter and importer \(\times\) year fixed effects" "Observations") fmt(a a %9.0fc )) 
		;
		#delimit cr
		